@@ -158,9 +158,9 @@ function form_save() {
 
 				if ($is_templated == '') {
 					$allow_nulls = true;
-				}elseif ($input_field['allow_nulls'] == 'on') {
+				} elseif ($input_field['allow_nulls'] == 'on') {
 					$allow_nulls = true;
-				}elseif (empty($input_field['allow_nulls'])) {
+				} elseif (empty($input_field['allow_nulls'])) {
 					$allow_nulls = false;
 				}
 
@@ -209,7 +209,7 @@ function form_save() {
 
 			if ($data_template_data_id) {
 				raise_message(1);
-			}else{
+			} else {
 				raise_message(2);
 			}
 		}
@@ -222,7 +222,7 @@ function form_save() {
 				otherwise there might be >1 */
 				if (isempty_request_var('_data_template_id')) {
 					$rrds[0]['id'] = get_nfilter_request_var('current_rrd');
-				}else{
+				} else {
 					$rrds = db_fetch_assoc_prepared('SELECT id
 						FROM data_template_rrd 
 						WHERE local_data_id = ?', 
@@ -233,7 +233,7 @@ function form_save() {
 				foreach ($rrds as $rrd) {
 					if (isempty_request_var('_data_template_id')) {
 						$name_modifier = '';
-					}else{
+					} else {
 						$name_modifier = '_' . $rrd['id'];
 					}
 
@@ -252,7 +252,7 @@ function form_save() {
 
 					if ($data_template_rrd_id) {
 						raise_message(1);
-					}else{
+					} else {
 						raise_message(2);
 					}
 				}
@@ -264,7 +264,7 @@ function form_save() {
 			if (get_request_var('data_template_id') != get_request_var('_data_template_id')) {
 				/* update all necessary template information */
 				change_data_template($local_data_id, get_request_var('data_template_id'));
-			}elseif (!isempty_request_var('data_template_id')) {
+			} elseif (!isempty_request_var('data_template_id')) {
 				update_data_source_data_query_cache($local_data_id);
 			}
 
@@ -293,9 +293,9 @@ function form_save() {
 
 	if (isset_request_var('save_component_data_source_new') && isempty_request_var('data_template_id')) {
 		header('Location: data_sources.php?header=false&action=ds_edit&host_id=' . get_request_var('host_id') . '&new=1');
-	}elseif ((is_error_message()) || (get_filter_request_var('data_template_id') != get_filter_request_var('_data_template_id')) || (get_filter_request_var('data_input_id') != get_filter_request_var('_data_input_id')) || (get_filter_request_var('host_id') != get_filter_request_var('_host_id'))) {
+	} elseif ((is_error_message()) || (get_filter_request_var('data_template_id') != get_filter_request_var('_data_template_id')) || (get_filter_request_var('data_input_id') != get_filter_request_var('_data_input_id')) || (get_filter_request_var('host_id') != get_filter_request_var('_host_id'))) {
 		header('Location: data_sources.php?header=false&action=ds_edit&id=' . (empty($local_data_id) ? get_filter_request_var('local_data_id') : $local_data_id) . '&host_id=' . get_request_var('host_id') . '&view_rrd=' . (isset_request_var('current_rrd') ? get_nfilter_request_var('current_rrd') : '0'));
-	}else{
+	} else {
 		header('Location: data_sources.php?header=false');
 	}
 }
@@ -319,7 +319,7 @@ function form_actions() {
 			if (get_nfilter_request_var('drp_action') == '1') { /* delete */
 				if (!isset_request_var('delete_type')) { 
 					set_request_var('delete_type', 1); 
-				}else{
+				} else {
 					get_filter_request_var('delete_type');
 				}
 
@@ -357,7 +357,7 @@ function form_actions() {
 				api_data_source_remove_multi($selected_items);
 
 				api_plugin_hook_function('data_source_remove', $selected_items);
-			}elseif (get_nfilter_request_var('drp_action') == '3') { /* change host */
+			} elseif (get_nfilter_request_var('drp_action') == '3') { // change host
 				get_filter_request_var('host_id');
 
 				for ($i=0;($i<count($selected_items));$i++) {
@@ -365,15 +365,15 @@ function form_actions() {
 					push_out_host(get_nfilter_request_var('host_id'), $selected_items[$i]);
 					update_data_source_title_cache($selected_items[$i]);
 				}
-			}elseif (get_nfilter_request_var('drp_action') == '6') { /* data source enable */
+			} elseif (get_nfilter_request_var('drp_action') == '6') { // data source enable
 				for ($i=0;($i<count($selected_items));$i++) {
 					api_data_source_enable($selected_items[$i]);
 				}
-			}elseif (get_nfilter_request_var('drp_action') == '7') { /* data source disable */
+			} elseif (get_nfilter_request_var('drp_action') == '7') { // data source disable
 				for ($i=0;($i<count($selected_items));$i++) {
 					api_data_source_disable($selected_items[$i]);
 				}
-			}elseif (get_nfilter_request_var('drp_action') == '8') { /* reapply suggested data source naming */
+			} elseif (get_nfilter_request_var('drp_action') == '8') { // reapply suggested data source naming
 				for ($i=0;($i<count($selected_items));$i++) {
 					api_reapply_suggested_data_source_title($selected_items[$i]);
 					update_data_source_title_cache($selected_items[$i]);
@@ -458,7 +458,7 @@ function form_actions() {
 				</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Delete Data Source', 'Delete Data Sources', sizeof($ds_array)) . "'>";
-		}elseif (get_nfilter_request_var('drp_action') == '3') { /* change host */
+		} elseif (get_nfilter_request_var('drp_action') == '3') { // change host
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __n('Choose a new Device for this Data Source and click \'Continue\'.', 'Choose a new Device for these Data Sources and click \'Continue\'', sizeof($ds_array)) . "</p>
@@ -468,7 +468,7 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Change Device') . "'>";
-		}elseif (get_nfilter_request_var('drp_action') == '6') { /* data source enable */
+		} elseif (get_nfilter_request_var('drp_action') == '6') { // data source enable
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __n('Click \'Continue\' to enable the following Data Source.', 'Click \'Continue\' to enable all following Data Sources.', sizeof($ds_array)) . "</p>
@@ -477,7 +477,7 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __n('Enable Data Source', 'Enable Data Sources', sizeof($ds_array)) . "'>";
-		}elseif (get_nfilter_request_var('drp_action') == '7') { /* data source disable */
+		} elseif (get_nfilter_request_var('drp_action') == '7') { // data source disable
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __n('Click \'Continue\' to disable the following Data Source.', 'Click \'Continue\' to disable all following Data Sources.', sizeof($ds_array)) . "</p>
@@ -486,7 +486,7 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Disable Data Source', 'Disable Data Sources', sizeof($ds_array)) . "'>";
-		}elseif (get_nfilter_request_var('drp_action') == '8') { /* reapply suggested data source naming */
+		} elseif (get_nfilter_request_var('drp_action') == '8') { // reapply suggested data source naming
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __n('Click \'Continue\' to re-apply the suggested name to the following Data Source.', 'Click \'Continue\' to re-apply the suggested names to all following Data Sources.', sizeof($ds_array)) . "</p>
@@ -495,14 +495,14 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Reapply Suggested Naming to Data Source', 'Reapply Suggested Naming to Data Sources', sizeof($ds_array)) . "'>";
-		}else{
+		} else {
 			$save['drp_action'] = get_nfilter_request_var('drp_action');
 			$save['ds_list'] = $ds_list;
 			$save['ds_array'] = (isset($ds_array)? $ds_array : array());
 			api_plugin_hook_function('data_source_action_prepare', $save);
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "'>";
 		}
-	}else{
+	} else {
 		print "<tr><td class='even'><span class='textError'>" . __('You must select at least one data source.') . "</span></td></tr>\n";
 		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
 	}
@@ -570,14 +570,14 @@ function data_edit($incform = true) {
 
 			if (sizeof($data_input_data) > 0) {
 				$old_value = $data_input_data['value'];
-			}else{
+			} else {
 				$old_value = '';
 			}
 
 			/* if data template then get t_value FROM template, else always allow user input */
 			if (empty($data['data_template_id'])) {
 				$can_template = 'on';
-			}else{
+			} else {
 				$can_template = db_fetch_cell_prepared('SELECT t_value 
 					FROM data_input_data 
 					WHERE data_template_data_id = ? AND data_input_field_id = ?', array($template_data['id'], $field['id']));
@@ -588,10 +588,10 @@ function data_edit($incform = true) {
 			if ((!empty($host['id'])) && (preg_match('/^' . VALID_HOST_FIELDS . '$/i', $field['type_code']))) {
 				print "<td style='width:50%;'><strong>" . $field['name'] . '</strong> ' . __('(From Device: %s)', $host['hostname']) . "</td>\n";
 				print "<td><em>$old_value</em></td>\n";
-			}elseif (empty($can_template)) {
+			} elseif (empty($can_template)) {
 				print "<td style='width:50%;'><strong>" . $field['name'] . '</strong> ' . __('(From Data Template)') . "</td>\n";
 				print '<td><em>' . (empty($old_value) ? __('Nothing Entered') : $old_value) . "</em></td>\n";
-			}else{
+			} else {
 				print "<td style='width:50%;'><strong>" . $field['name'] . "</strong></td>\n";
 				print '<td>';
 
@@ -604,7 +604,7 @@ function data_edit($incform = true) {
 
 			$i++;
 		}
-		}else{
+		} else {
 			print '<tr><td><em>' . __('No Input Fields for the Selected Data Input Source') . '</em></td></tr>';
 		}
 
@@ -656,15 +656,31 @@ function ds_edit() {
 	api_plugin_hook('data_source_edit_top');
 
 	$use_data_template = true;
-	$host_id = 0;
+	$host_id           = 0;
+	$data_template     = array();
 
 	if (!isempty_request_var('id')) {
-		$data_local = db_fetch_row_prepared('SELECT host_id, data_template_id FROM data_local WHERE id = ?', array(get_request_var('id')));
-		$data       = db_fetch_row_prepared('SELECT * FROM data_template_data WHERE local_data_id = ?', array(get_request_var('id')));
+		$data_local = db_fetch_row_prepared('SELECT host_id, data_template_id 
+			FROM data_local 
+			WHERE id = ?', 
+			array(get_request_var('id')));
+
+		$data = db_fetch_row_prepared('SELECT * 
+			FROM data_template_data 
+			WHERE local_data_id = ?', 
+			array(get_request_var('id')));
 
 		if (isset($data_local['data_template_id']) && $data_local['data_template_id'] >= 0) {
-			$data_template      = db_fetch_row_prepared('SELECT id, name FROM data_template WHERE id = ?', array($data_local['data_template_id']));
-			$data_template_data = db_fetch_row_prepared('SELECT * FROM data_template_data WHERE data_template_id = ? AND local_data_id = 0', array($data_local['data_template_id']));
+			$data_template = db_fetch_row_prepared('SELECT id, name 
+				FROM data_template 
+				WHERE id = ?', 
+				array($data_local['data_template_id']));
+
+			$data_template_data = db_fetch_row_prepared('SELECT * 
+				FROM data_template_data 
+				WHERE data_template_id = ? 
+				AND local_data_id = 0', 
+				array($data_local['data_template_id']));
 		} else {
 			$_SESSION['sess_messages'] = __('Data Source %d does not exist.', get_request_var('id'));
 			header ('Location: data_sources.php');
@@ -676,7 +692,7 @@ function ds_edit() {
 		if (empty($data_local['data_template_id'])) {
 			$use_data_template = false;
 		}
-	}else{
+	} else {
 		$header_label = __('Data Template Selection [new]');
 
 		$use_data_template = false;
@@ -686,7 +702,7 @@ function ds_edit() {
 	if (isset_request_var('debug')) {
 		if (get_nfilter_request_var('debug') == '0') {
 			kill_session_var('ds_debug_mode');
-		}elseif (get_nfilter_request_var('debug') == '1') {
+		} elseif (get_nfilter_request_var('debug') == '1') {
 			$_SESSION['ds_debug_mode'] = true;
 		}
 	}
@@ -695,7 +711,7 @@ function ds_edit() {
 	if (isset_request_var('info')) {
 		if (get_nfilter_request_var('info') == '0') {
 			kill_session_var('ds_info_mode');
-		}elseif (get_nfilter_request_var('info') == '1') {
+		} elseif (get_nfilter_request_var('info') == '1') {
 			$_SESSION['ds_info_mode'] = true;
 		}
 	}
@@ -706,18 +722,18 @@ function ds_edit() {
 		?>
 		<table style='width:100%'>
 			<tr>
-				<td class='textInfo left' colspan='2' valign='top'>
+				<td class='textInfo left' style='vertical-align:top;'>
 					<?php print htmlspecialchars(get_data_source_title(get_request_var('id')));?>
 				</td>
-				<td class='textInfo right' valign='top'>
-					<span class='linkMarker'>*<a class='hyperLink' href='<?php print htmlspecialchars('data_sources.php?action=ds_edit&id=' . (isset_request_var('id') ? get_request_var('id') : '0') . '&debug=' . (isset($_SESSION['ds_debug_mode']) ? '0' : '1'));?>'><?php print (isset($_SESSION['ds_debug_mode']) ? __('Turn Off Data Source Debug Mode.') : __('Turn On Data Source Debug Mode.'));?></a><br>
-					<span class='linkMarker'>*<a class='hyperLink' href='<?php print htmlspecialchars('data_sources.php?action=ds_edit&id=' . (isset_request_var('id') ? get_request_var('id') : '0') . '&info=' . (isset($_SESSION['ds_info_mode']) ? '0' : '1'));?>'><?php print (isset($_SESSION['ds_info_mode']) ? __('Turn Off Data Source Info Mode.') : __('Turn On Data Source Info Mode.'));?></a><br>
+				<td class='textInfo right' style='vertical-align:top;'>
+					<span class='linkMarker'>*</span><a class='hyperLink' href='<?php print htmlspecialchars('data_sources.php?action=ds_edit&id=' . (isset_request_var('id') ? get_request_var('id') : '0') . '&debug=' . (isset($_SESSION['ds_debug_mode']) ? '0' : '1'));?>'><?php print (isset($_SESSION['ds_debug_mode']) ? __('Turn Off Data Source Debug Mode.') : __('Turn On Data Source Debug Mode.'));?></a><br>
+					<span class='linkMarker'>*</span><a class='hyperLink' href='<?php print htmlspecialchars('data_sources.php?action=ds_edit&id=' . (isset_request_var('id') ? get_request_var('id') : '0') . '&info=' . (isset($_SESSION['ds_info_mode']) ? '0' : '1'));?>'><?php print (isset($_SESSION['ds_info_mode']) ? __('Turn Off Data Source Info Mode.') : __('Turn On Data Source Info Mode.'));?></a><br>
 					<?php
 						if (!empty($data_template['id'])) {
-							?><span class='linkMarker'>*<a class='hyperLink' href='<?php print htmlspecialchars('data_templates.php?action=template_edit&id=' . (isset($data_template['id']) ? $data_template['id'] : '0'));?>'><?php print __('Edit Data Template.');?></a><br><?php
+							?><span class='linkMarker'>*</span><a class='hyperLink' href='<?php print htmlspecialchars('data_templates.php?action=template_edit&id=' . (isset($data_template['id']) ? $data_template['id'] : '0'));?>'><?php print __('Edit Data Template.');?></a><br><?php
 						}
 						if (!isempty_request_var('host_id') || !empty($data_local['host_id'])) {
-							?><span class='linkMarker'>*<a class='hyperLink' href='<?php print htmlspecialchars('host.php?action=edit&id=' . (isset_request_var('host_id') ? get_request_var('host_id') : $data_local['host_id']));?>'><?php print __('Edit Device.');?></a><br><?php
+							?><span class='linkMarker'>*</span><a class='hyperLink' href='<?php print htmlspecialchars('host.php?action=edit&id=' . (isset_request_var('host_id') ? get_request_var('host_id') : $data_local['host_id']));?>'><?php print __('Edit Device.');?></a><br><?php
 						}
 					?>
 				</td>
@@ -729,7 +745,7 @@ function ds_edit() {
 
 	form_start('data_sources.php', 'data_source');
 
-	html_start_box($header_label, '100%', '', '3', 'center', '');
+	html_start_box($header_label, '100%', true, '3', 'center', '');
 
 	if (sizeof($data_template)) {
 		$data_sources = db_fetch_cell_prepared('SELECT 
@@ -753,12 +769,20 @@ function ds_edit() {
 		}
 
 		$dtsql = 'SELECT id, name FROM data_template WHERE id IN(' . implode(',', $dtids) . ') ORDER BY name';
-	}else{
+	} else {
 		$data_sources = '';
 
 		$dtsql = 'SELECT id, name FROM data_template ORDER BY name';
 	}
 
+	if (get_request_var('host_id') > 0) {
+		$value = db_fetch_cell_prepared('SELECT description 
+			FROM host WHERE id = ?', 
+			(isset_request_var('host_id') ? array(get_request_var('host_id')) : (isset($data_local['host_id']) ? array($data_local['host_id']):array(0))));
+	} else {
+		$value = '';
+	}
+
 	$form_array = array(
 		'data_template_id' => array(
 			'method' => 'drop_sql',
@@ -772,11 +796,11 @@ function ds_edit() {
 			'method' => 'drop_callback',
 			'friendly_name' => __('Device'),
 			'description' => __('Choose the Device that this Data Source belongs to.'),
-			'none_value' => 'None',
+			'none_value' => __('None'),
 			'sql' => 'SELECT id, description as name FROM host ORDER BY name',
 			'action' => 'ajax_hosts_noany',
 			'id' => (isset_request_var('host_id') ? get_request_var('host_id') : (isset($data_local['host_id']) ? $data_local['host_id']:0)),
-			'value' => db_fetch_cell_prepared('SELECT description FROM host WHERE id = ?', (isset_request_var('host_id') ? array(get_request_var('host_id')) : (isset($data_local['host_id']) ? array($data_local['host_id']):array(0)))),
+			'value' => $value
 			),
 		'_data_template_id' => array(
 			'method' => 'hidden',
@@ -811,13 +835,13 @@ function ds_edit() {
 		)
 	);
 
-	html_end_box();
+	html_end_box(true, true);
 
 	/* only display the "inputs" area if we are using a data template for this data source */
 	if (!empty($data['data_template_id'])) {
 		$template_data_rrds = db_fetch_assoc_prepared('SELECT * FROM data_template_rrd WHERE local_data_id = ? ORDER BY data_source_name', array(get_request_var('id')));
 
-		html_start_box( __('Supplemental Data Template Data'), '100%', '', '3', 'center', '');
+		html_start_box( __('Supplemental Data Template Data'), '100%', true, '3', 'center', '');
 
 		draw_nontemplated_fields_data_source($data['data_template_id'], $data['local_data_id'], $data, '|field|', __('Data Source Fields'), true, true, 0);
 		draw_nontemplated_fields_data_source_item($data['data_template_id'], $template_data_rrds, '|field|_|id|', __('Data Source Item Fields'), true, true, true, 0);
@@ -825,11 +849,11 @@ function ds_edit() {
 
 		form_hidden_box('save_component_data','1','');
 
-		html_end_box();
+		html_end_box(true, true);
 	}
 
 	if (((isset_request_var('id')) || (isset_request_var('new'))) && (empty($data['data_template_id']))) {
-		html_start_box( __('Data Source'), '100%', '', '3', 'center', '');
+		html_start_box( __('Data Source'), '100%', true, '3', 'center', '');
 
 		$form_array = array();
 
@@ -857,7 +881,7 @@ function ds_edit() {
 			)
 		);
 
-		html_end_box();
+		html_end_box(true, true);
 
 		/* fetch ALL rrd's for this data source */
 		if (!isempty_request_var('id')) {
@@ -877,7 +901,7 @@ function ds_edit() {
 			$rrd_template = db_fetch_row_prepared('SELECT * FROM data_template_rrd WHERE id = ?', array($local_data_template_rrd_id));
 
 			$header_label = '[edit: ' . $rrd['data_source_name'] . ']';
-		}else{
+		} else {
 			$header_label = '';
 		}
 
@@ -896,26 +920,26 @@ function ds_edit() {
 				}
 
 				print "<td></td></tr></table>\n";
-			}elseif (sizeof($template_data_rrds) == 1) {
+			} elseif (sizeof($template_data_rrds) == 1) {
 				set_request_var('view_rrd', $template_data_rrds[0]['id']);
 			}
 		}
 
-		html_start_box('', '100%', '', '3', 'center', '');
+		html_start_box('', '100%', true, '3', 'center', '');
 
-		print "<tr>
-			<td class='textHeaderDark left'>
+		print "<div class='tableHeader'>
+			<div class='tableSubHeaderColumn left'>
 				" . __('Data Source Item %s', $header_label) . "
-			</td>
-			<td class='textHeaderDark right'>
+			</div>
+			<div class='tableSubHeaderColumn right'>
 				" . ((!isempty_request_var('id') && (empty($data_template['id']))) ? "<a class='linkOverDark' href='" . htmlspecialchars('data_sources.php?action=rrd_add&id=' . get_request_var('id')) . "'>" . __('New') . "</a>&nbsp;" : '') . "
-			</td>
-		</tr>\n";
+			</div>
+		</div>\n";
 
 		/* data input fields list */
 		if ((empty($data['data_input_id'])) || (db_fetch_cell_prepared('SELECT type_id FROM data_input WHERE id = ?', array($data['data_input_id'])) > '1')) {
 			unset($struct_data_source_item['data_input_field_id']);
-		}else{
+		} else {
 			$struct_data_source_item['data_input_field_id']['sql'] = "SELECT id,CONCAT(data_name,' - ',name) as name FROM data_input_fields WHERE data_input_id=" . $data['data_input_id'] . " and input_output='out' and update_rra='on' order by data_name,name";
 		}
 
@@ -953,7 +977,7 @@ function ds_edit() {
 			)
 		);
 
-		html_end_box();
+		html_end_box(true, true);
 
 		/* data source data goes here */
 		data_edit(false);
@@ -1000,7 +1024,7 @@ function ds_edit() {
 
 	if ((isset_request_var('id')) || (isset_request_var('new'))) {
 		form_hidden_box('save_component_data_source','1','');
-	}else{
+	} else {
 		form_hidden_box('save_component_data_source_new','1','');
 	}
 
@@ -1018,7 +1042,7 @@ function get_poller_interval($seconds) {
 		return '<em>' . __('%d Seconds', $seconds) . '</em>';
 	}else if ($seconds == 60) {
 		return  __('1 Minute');
-	}else{
+	} else {
 		return '<em>' . __('%d Minutes', ($seconds / 60)) . '</em>';
 	}
 }
@@ -1085,13 +1109,13 @@ function ds() {
 
 	if (get_request_var('rows') == -1) {
 		$rows = read_config_option('num_rows_table');
-	}else{
+	} else {
 		$rows = get_request_var('rows');
 	}
 
 	if (get_request_var('host_id') > 0) {
 		$host = db_fetch_row_prepared('SELECT hostname FROM host WHERE id = ?', array(get_request_var('host_id')));
-	}else{
+	} else {
 		$host = array();
 	}
 
@@ -1133,8 +1157,14 @@ function ds() {
 	<?php
 
 	if (read_config_option('grds_creation_method') == 1 ) {
-		$add_url = htmlspecialchars('data_sources.php?action=ds_edit&host_id=' . get_request_var('host_id'));
-	}else{
+		if (get_request_var('host_id') == '-1') {
+			$new_host_id = 0;
+		} else {
+			$new_host_id = get_request_var('host_id');
+		}
+
+		$add_url = htmlspecialchars('data_sources.php?action=ds_edit&host_id=' . $new_host_id);
+	} else {
 		$add_url = '';
 	}
 
@@ -1254,45 +1284,45 @@ function ds() {
 		$sql_where1 = "WHERE (dtd.name_cache RLIKE '" . get_request_var('rfilter') . "'" .
 			" OR dtd.local_data_id RLIKE '" . get_request_var('rfilter') . "'" .
 			" OR dt.name RLIKE '" . get_request_var('rfilter') . "')";
-	}else{
+	} else {
 		$sql_where1 = '';
 	}
 
 	if (get_request_var('host_id') == '-1') {
 		/* Show all items */
-	}elseif (isempty_request_var('host_id')) {
+	} elseif (isempty_request_var('host_id')) {
 		$sql_where1 .= (strlen($sql_where1) ? ' AND':'WHERE') . ' (dl.host_id=0 OR dl.host_id IS NULL)';
-	}elseif (!isempty_request_var('host_id')) {
+	} elseif (!isempty_request_var('host_id')) {
 		$sql_where1 .= (strlen($sql_where1) ? ' AND':'WHERE') . ' dl.host_id=' . get_request_var('host_id');
 	}
 
 	if (get_request_var('template_id') == '-1') {
 		/* Show all items */
-	}elseif (get_request_var('template_id') == '0') {
+	} elseif (get_request_var('template_id') == '0') {
 		$sql_where1 .= (strlen($sql_where1) ? ' AND':'WHERE') . ' dtd.data_template_id=0';
-	}elseif (!isempty_request_var('host_id')) {
+	} elseif (!isempty_request_var('host_id')) {
 		$sql_where1 .= (strlen($sql_where1) ? ' AND':'WHERE') . ' dtd.data_template_id=' . get_request_var('template_id');
 	}
 
 	if (get_request_var('profile') == '-1') {
 		/* Show all items */
-	}else{
+	} else {
 		$sql_where1 .= (strlen($sql_where1) ? ' AND':'WHERE') . ' dtd.data_source_profile_id=' . get_request_var('profile');
 	}
 
 	if (get_request_var('status') == '-1') {
 		/* Show all items */
-	}elseif (get_request_var('status') == '1') {
+	} elseif (get_request_var('status') == '1') {
 		$sql_where1 .= (strlen($sql_where1) ? ' AND':'WHERE') . ' dtd.active="on"';
-	}else{
+	} else {
 		$sql_where1 .= (strlen($sql_where1) ? ' AND':'WHERE') . ' dtd.active=""';
 	}
 
 	if (get_request_var('orphans') == '0') {
 		$sql_having = 'HAVING deletable>0';
-	}elseif (get_request_var('orphans') == 1) {
+	} elseif (get_request_var('orphans') == 1) {
 		$sql_having = 'HAVING deletable=0';
-	}else{
+	} else {
 		$sql_having = '';
 	}
 
@@ -1361,7 +1391,7 @@ function ds() {
 		foreach ($data_sources as $data_source) {
 			if ($data_source['deletable'] > 0) {
 				$disabled = true;
-			}else{
+			} else {
 				$disabled = false;
 			}
 
@@ -1398,7 +1428,7 @@ function ds() {
 			form_checkbox_cell($data_source['name_cache'], $data_source['local_data_id'], $disabled);
 			form_end_row();
 		}
-	}else{
+	} else {
 		print "<tr class='tableRow'><td colspan='7'><em>" . __('No Data Sources Found') . "</em></td></tr>";
 	}
 
