@@ -141,11 +141,11 @@ function parse_validate_graph_template_id($variable) {
 		if (is_numeric($template_parts[0]) && is_numeric($template_parts[1])) {
 			set_request_var('graph_template_id', $template_parts[0]);
 			$output_type_id = $template_parts[1];
-		}else{
+		} else {
 			cacti_log('ERROR: Unable to parse graph_template_id with value ' . get_nfilter_request_var($variable), false, 'WEBUI');
 			exit;
 		}
-	}else{
+	} else {
 		get_filter_request_var($variable);
 	}
 
@@ -187,7 +187,7 @@ function form_save() {
 		if (isset($return_array['local_graph_id'])) {
 			$local_graph_id = $return_array['local_graph_id'];
 			header('Location: graphs.php?action=graph_edit&header=false&id=' . $local_graph_id);
-		}else{
+		} else {
 			header('Location: graphs.php?header=false');
 		}
 
@@ -247,7 +247,7 @@ function form_save() {
 
 			if ($graph_templates_graph_id) {
 				raise_message(1);
-			}else{
+			} else {
 				raise_message(2);
 			}
 
@@ -264,7 +264,7 @@ function form_save() {
 
 		if ((!is_error_message()) && ($gt_id_unparsed != $gt_id_prev_unparsed)) {
 			change_graph_template($local_graph_id, $gt_id_unparsed);
-		}elseif (!isempty_request_var('graph_template_id')) {
+		} elseif (!isempty_request_var('graph_template_id')) {
 			update_graph_data_query_cache($local_graph_id);
 		}
 	}
@@ -319,9 +319,9 @@ function form_save() {
 
 	if ((isset_request_var('save_component_graph_new')) && (isempty_request_var('graph_template_id'))) {
 		header('Location: graphs.php?action=graph_edit&header=false&host_id=' . get_nfilter_request_var('host_id') . '&new=1');
-	}elseif ((is_error_message()) || (isempty_request_var('local_graph_id')) || (get_nfilter_request_var('graph_template_id') != get_nfilter_request_var('graph_template_id_prev')) || (get_nfilter_request_var('host_id') != get_nfilter_request_var('host_id_prev'))) {
+	} elseif ((is_error_message()) || (isempty_request_var('local_graph_id')) || (get_nfilter_request_var('graph_template_id') != get_nfilter_request_var('graph_template_id_prev')) || (get_nfilter_request_var('host_id') != get_nfilter_request_var('host_id_prev'))) {
 		header('Location: graphs.php?action=graph_edit&header=false&id=' . (empty($local_graph_id) ? get_nfilter_request_var('local_graph_id') : $local_graph_id) . (isset_request_var('host_id') ? '&host_id=' . get_nfilter_request_var('host_id') : ''));
-	}else{
+	} else {
 		header('Location: graphs.php?header=false');
 	}
 }
@@ -343,7 +343,7 @@ function get_current_graph_template_name($local_graph_id) {
 			ON gl.snmp_query_graph_id=sqg.id 
 			WHERE gl.id = ?', 
 			array($local_graph_id));
-	}else{
+	} else {
 		return db_fetch_cell_prepared('SELECT gt.name
 			FROM graph_templates AS gt
 			INNER JOIN graph_local AS gl
@@ -368,7 +368,7 @@ function get_current_graph_template($local_graph_id) {
 		$local_data_id = db_fetch_cell("SELECT DISTINCT local_data_id 
 			FROM data_template_rrd 
 			WHERE id IN($task_items)");
-	}else{
+	} else {
 		$local_data_id = 0;
 	}
 
@@ -395,10 +395,10 @@ function get_current_graph_template($local_graph_id) {
 
 		if (!empty($snmp_query_graph_id)) {
 			return $graph_local['graph_template_id'] . '_' . $snmp_query_graph_id;
-		}else{
+		} else {
 			return $graph_local['graph_template_id'];
 		}
-	}else{
+	} else {
 		return $graph_local['graph_template_id'];
 	}
 }
@@ -406,7 +406,7 @@ function get_current_graph_template($local_graph_id) {
 function get_common_graph_templates(&$graph) {
 	if (sizeof($graph)) {
 		$dqid = db_fetch_cell_prepared('SELECT snmp_query_id FROM graph_local WHERE id = ?', array($graph['local_graph_id']));
-	}else{
+	} else {
 		$dqid = '';
 	}
 
@@ -438,9 +438,9 @@ function get_common_graph_templates(&$graph) {
 			FROM snmp_query_graph 
 			WHERE (snmp_query_id = " . $dqid . "
 			AND id IN (" . $ids . ")) OR graph_template_id IN (" . $gtids . ") ORDER BY name";
-	}elseif (sizeof($graph)) {
+	} elseif (sizeof($graph)) {
 		$gtsql = 'SELECT gt.id, gt.name FROM graph_templates AS gt WHERE gt.id=' . $graph['graph_template_id'] . ' ORDER BY name';
-	}else{
+	} else {
 		$gtsql = 'SELECT gt.id, gt.name FROM graph_templates AS gt ORDER BY name';
 	}
 
@@ -459,13 +459,13 @@ function form_actions() {
 		$selected_items = sanitize_unserialize_selected_items(get_nfilter_request_var('selected_items'));
 
 		if ($selected_items != false) {
-			if (get_request_var('drp_action') == '1') { /* delete */
+			if (get_request_var('drp_action') == '1') { // delete
 				if (!isset_request_var('delete_type')) {
 					set_request_var('delete_type', 1);
 				}
 
 				switch (get_nfilter_request_var('delete_type')) {
-					case '2': /* delete all data sources referenced by this graph */
+					case '2': // delete all data sources referenced by this graph
 						$all_data_sources = array_rekey(db_fetch_assoc('SELECT DISTINCT dtd.local_data_id
 							FROM data_template_data AS dtd
 							INNER JOIN data_template_rrd AS dtr
@@ -518,7 +518,7 @@ function form_actions() {
 
 						break;
 				}
-			}elseif (get_request_var('drp_action') == '2') { /* change graph template */
+			} elseif (get_request_var('drp_action') == '2') { // change graph template
 				$gt_id_unparsed      = get_nfilter_request_var('graph_template_id');
 				$gt_id_prev_unparsed = get_nfilter_request_var('graph_template_id_prev');
 				parse_validate_graph_template_id('graph_template_id');
@@ -526,21 +526,21 @@ function form_actions() {
 				for ($i=0;($i<count($selected_items));$i++) {
 					change_graph_template($selected_items[$i], $gt_id_unparsed, true);
 				}
-			}elseif (get_request_var('drp_action') == '3') { /* duplicate */
+			} elseif (get_request_var('drp_action') == '3') { // duplicate 
 				for ($i=0;($i<count($selected_items));$i++) {
 					duplicate_graph($selected_items[$i], 0, get_nfilter_request_var('title_format'));
 				}
-			}elseif (get_request_var('drp_action') == '4') { /* graph -> graph template */
+			} elseif (get_request_var('drp_action') == '4') { // graph -> graph template
 				for ($i=0;($i<count($selected_items));$i++) {
 					graph_to_graph_template($selected_items[$i], get_nfilter_request_var('title_format'));
 				}
-			}elseif (preg_match('/^tr_([0-9]+)$/', get_request_var('drp_action'), $matches)) { /* place on tree */
+			} elseif (preg_match('/^tr_([0-9]+)$/', get_request_var('drp_action'), $matches)) { // place on tree
 				get_filter_request_var('tree_id');
 				get_filter_request_var('tree_item_id');
 				for ($i=0;($i<count($selected_items));$i++) {
 					api_tree_item_save(0, get_nfilter_request_var('tree_id'), TREE_ITEM_TYPE_GRAPH, get_nfilter_request_var('tree_item_id'), '', $selected_items[$i], 0, 0, 0, false);
 				}
-			}elseif (get_request_var('drp_action') == '5') { /* change host */
+			} elseif (get_request_var('drp_action') == '5') { // change host
 				get_filter_request_var('host_id');
 				$failures = false;
 				for ($i=0;($i<count($selected_items));$i++) {
@@ -552,12 +552,12 @@ function form_actions() {
 						raise_message(33);
 					}
 				}
-			}elseif (get_request_var('drp_action') == '6') { /* reapply suggested naming */
+			} elseif (get_request_var('drp_action') == '6') { // reapply suggested naming
 				for ($i=0;($i<count($selected_items));$i++) {
 					api_reapply_suggested_graph_title($selected_items[$i]);
 					update_graph_title_cache($selected_items[$i]);
 				}
-			}elseif (get_request_var('drp_action') == '9' || get_request_var('drp_action') == '10') {
+			} elseif (get_request_var('drp_action') == '9' || get_request_var('drp_action') == '10') {
 				/* get common info - not dependant on template/no template*/
 				$local_graph_id = 0; // this will be a new graph
 				$member_graphs  = $selected_items;
@@ -699,7 +699,7 @@ function form_actions() {
 
 				header("Location: aggregate_graphs.php?header=false&action=edit&tab=details&id=$local_graph_id");
 				exit;
-			}elseif (get_request_var('drp_action') == '8') { /* automation */
+			} elseif (get_request_var('drp_action') == '8') { // automation
 				cacti_log('automation_graph_action_execute called: ' . $action, true, 'AUTM8 TRACE', POLLER_VERBOSITY_MEDIUM);
 
 				/* work on all selected graphs */
@@ -746,7 +746,7 @@ function form_actions() {
 	html_start_box($graph_actions{get_request_var('drp_action')}, '60%', '', '3', 'center', '');
 
 	if (isset($graph_array) && sizeof($graph_array)) {
-		if (get_request_var('drp_action') == '1') { /* delete */
+		if (get_request_var('drp_action') == '1') { // delete
 			/* find out which (if any) data sources are being used by this graph, so we can tell the user */
 			if (isset($graph_array) && sizeof($graph_array)) {
 				$data_sources = array_rekey(
@@ -816,7 +816,7 @@ function form_actions() {
 			print "</td></tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') ."' title='" . __('Delete Graph(s)') . "'>";
-		} elseif (get_request_var('drp_action') == '2') { /* change graph template */
+		} elseif (get_request_var('drp_action') == '2') { // change graph template
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Choose a Graph Template and click \'Continue\' to change the Graph Template for the following Graph(s). Please note, that only compatible Graph Templates will be displayed.  Compatible is identified by those having identical Data Sources.') . "</p>
@@ -840,7 +840,7 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Change Graph Template') . "'>";
-		}elseif (get_request_var('drp_action') == '3') { /* duplicate */
+		} elseif (get_request_var('drp_action') == '3') { // duplicate
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Click \'Continue\' to duplicate the following Graph(s). You can optionally change the title format for the new Graph(s).') . "</p>
@@ -851,7 +851,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Duplicate Graph(s)') . "'>";
-		}elseif (get_request_var('drp_action') == '4') { /* graph -> graph template */
+		} elseif (get_request_var('drp_action') == '4') { // graph -> graph template
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Click \'Continue\' to convert the following Graph(s) into Graph Template(s).  You can optionally change the title format for the new Graph Template(s).') . "</p>
@@ -862,7 +862,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Convert to Graph Template') . "'>";
-		} elseif (preg_match('/^tr_([0-9]+)$/', get_request_var('drp_action'), $matches)) { /* place on tree */
+		} elseif (preg_match('/^tr_([0-9]+)$/', get_request_var('drp_action'), $matches)) { // place on tree
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Click \'Continue\' to place the following Graph(s) under the Tree Branch selected below.') . "</p>
@@ -877,7 +877,7 @@ function form_actions() {
 				<input type='hidden' name='tree_id' value='" . htmlspecialchars($matches[1]) . "'>\n";
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Place Graph(s) on Tree') . "'>";
-		} elseif (get_request_var('drp_action') == '5') { /* change host */
+		} elseif (get_request_var('drp_action') == '5') { // change host
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Choose a new Device for these Graph(s) and click \'Continue\'.') . "</p>
@@ -891,7 +891,7 @@ function form_actions() {
 			</tr>\n";
 
 			$save_html = "<input type='button' value='Cancel' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='Continue' title='Change Graph(s) Associated Device'>";
-		} elseif (get_request_var('drp_action') == '6') { /* reapply suggested naming to host */
+		} elseif (get_request_var('drp_action') == '6') { // reapply suggested naming to host
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Click \'Continue\' to re-apply suggested naming to the following Graph(s).') . "</p>
@@ -931,6 +931,8 @@ function form_actions() {
 				}
 				print "</tr>\n";
 
+				print "<tr><td>";
+
 				$ttitle = $graph_array[0];
 
 				/* aggregate form */
@@ -950,6 +952,8 @@ function form_actions() {
 				# draw all graph items of first graph, including a html_start_box
 				draw_aggregate_graph_items_list(0, $graph_template);
 
+				print "</td></tr>";
+
 				# again, a new html_start_box. Using the one from above would yield ugly formatted NO and YES buttons
 				html_start_box(__('Please confirm'), '100%', '', '3', 'center', '');
 
@@ -999,13 +1003,13 @@ function form_actions() {
 
 						if (id.indexOf('skip') > 0) {
 							altId = id.replace('skip', 'total');
-						}else{
+						} else {
 							altId = id.replace('total', 'skip');
 						}
 
 						if ($('#'+id).is(':checked')) {
 							$('#'+altId).prop('checked', false);
-						}else{
+						} else {
 							$('#'+altId).prop('checked', true);
 						}
 					});
@@ -1020,10 +1024,10 @@ function form_actions() {
 				<?php
 
 				$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Resize Selected Graph(s)') . "'>";
-			}else{
+			} else {
 				$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
 			}
-		}elseif (get_request_var('drp_action') == '10') { /* aggregate template */
+		} elseif (get_request_var('drp_action') == '10') { // aggregate template
 			include_once('./lib/api_aggregate.php');
 
 			/* initialize return code and graphs array */
@@ -1063,7 +1067,7 @@ function form_actions() {
 					</tr></table></td></tr>\n";
 
 					$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Create Aggregate') . "'>";
-				}else{
+				} else {
 					print "<tr>
 						<td class='textArea'>
 							<p>" . __('There are presently no Aggregate Templates defined for this Graph Template.  Please either first create an Aggregate Template for the selected Graphs Graph Template and try again, or simply crease an un-templated Aggregate Graph.') . "</p>
@@ -1073,10 +1077,10 @@ function form_actions() {
 
 					$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
 				}
-			}else{
+			} else {
 				$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
 			}
-		}elseif (get_request_var('drp_action') == 8) { /* automation */
+		} elseif (get_request_var('drp_action') == 8) { // automation
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Click \'Continue\' to apply Automation Rules to the following Graphs.') . "</p>
@@ -1094,7 +1098,7 @@ function form_actions() {
 
 			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "'>";
 		}
-	}else{
+	} else {
 		print "<tr><td class='even'><span class='textError'>" . __('You must select at least one Graph.') . "</span></td></tr>\n";
 
 		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
@@ -1131,7 +1135,7 @@ function item() {
 		$template_item_list = array();
 
 		$header_label = __('Graph Items [new]');
-	}else{
+	} else {
 		$template_item_list = db_fetch_assoc_prepared('SELECT
 			gti.id, gti.text_format, gti.value, gti.hard_return, gti.graph_type_id, gti.alpha, gti.textalign,
 			gti.consolidation_function_id, dtr.data_source_name, cd.name AS cdef_name, c.hex
@@ -1157,7 +1161,7 @@ function item() {
 
 	if (empty($graph_template_id)) {
 		$add_text = 'graphs_items.php?action=item_edit&local_graph_id=' . get_request_var('id') . "&host_id=$host_id";
-	}else{
+	} else {
 		$add_text = '';
 	}
 
@@ -1183,7 +1187,7 @@ function item() {
    ------------------------------------ */
 
 function graph_edit() {
-	global $struct_graph, $image_types, $consolidation_functions, $graph_item_types, $struct_graph_item;
+	global $config, $struct_graph, $image_types, $consolidation_functions, $graph_item_types, $struct_graph_item;
 
 	/* ================= input validation ================= */
 	get_filter_request_var('id');
@@ -1203,12 +1207,12 @@ function graph_edit() {
 		if (get_request_var('id') != $_SESSION['sess_graph_lock_id'] && !empty($local_graph_template_graph_id)) {
 			$locked = true;
 			$_SESSION['sess_graph_locked'] = $locked;
-		}elseif (empty($local_graph_template_graph_id)) {
+		} elseif (empty($local_graph_template_graph_id)) {
 			$locked = false;
 			$_SESSION['sess_graph_locked'] = $locked;
-		}elseif (isset($_SESSION['sess_graph_locked'])) {
+		} elseif (isset($_SESSION['sess_graph_locked'])) {
 			$locked = $_SESSION['sess_graph_locked'];
-		}else{
+		} else {
 			$locked = true;
 			$_SESSION['sess_graph_locked'] = $locked;
 		}
@@ -1235,18 +1239,18 @@ function graph_edit() {
 			exit;
 		}
 
-		$header_label = __('Graph Template Selection [edit: %s]', htmlspecialchars(get_graph_title(get_request_var('id'))));
+		$header_label = __('Graph [edit: %s]', htmlspecialchars(get_graph_title(get_request_var('id'))));
 
 		if ($graph['graph_template_id'] == '0') {
 			$use_graph_template = 'false';
 		}
-	}else{
-		$header_label = __('Graph Template Selection [new]');
+	} else {
+		$header_label = __('Graph [new]');
 		$use_graph_template = false;
 
 		if (isset_request_var('host_id') && get_filter_request_var('host_id') > 0) {
 			$host_id = get_request_var('host_id');
-		}else{
+		} else {
 			$host_id = 0;
 		}
 
@@ -1259,7 +1263,7 @@ function graph_edit() {
 	if (isset_request_var('debug')) {
 		if (get_nfilter_request_var('debug') == '0') {
 			kill_session_var('graph_debug_mode');
-		}elseif (get_nfilter_request_var('debug') == '1') {
+		} elseif (get_nfilter_request_var('debug') == '1') {
 			$_SESSION['graph_debug_mode'] = true;
 		}
 	}
@@ -1267,17 +1271,17 @@ function graph_edit() {
 	if (!isempty_request_var('id')) {
 		if (isset($_SESSION['graph_debug_mode'])) {
 			$message = __('Turn Off Graph Debug Mode.');
-		}else{
+		} else {
 			$message = __('Turn On Graph Debug Mode.');
 		}
 
 		?>
 		<table style='width:100%;'>
 			<tr>
-				<td class='textInfo left' colspan='2' valign='top'>
+				<td class='textInfo left' style='vertical-align:top'>
 					<?php print htmlspecialchars(get_graph_title(get_request_var('id')));?>
 				</td>
-				<td class='textInfo right' align='right' valign='top'>
+				<td class='textInfo right' style='vertical-align:top;'>
 					<span class='linkMarker'>*<a class='hyperLink' href='<?php print htmlspecialchars('graphs.php?action=graph_edit&id=' . (isset_request_var('id') ? get_request_var('id') : '0') . '&debug=' . (isset($_SESSION['graph_debug_mode']) ? '0' : '1'));?>'><?php print $message;?></a></span><br>
 					<?php
 						if (!empty($graph['graph_template_id'])) {
@@ -1288,7 +1292,7 @@ function graph_edit() {
 						}
 						if ($locked) {
 							?><span class='linkMarker'>*<a href='#' class='hyperLink' id='unlockid'><?php print __('Unlock Graph.');?></a></span><?php
-						}else{
+						} else {
 							?><span class='linkMarker'>*<a href='#' class='hyperLink' id='lockid'><?php print __('Lock Graph.');?></a></span><?php
 						}
 					?>
@@ -1300,13 +1304,13 @@ function graph_edit() {
 
 	form_start('graphs.php');
 
-	html_start_box($header_label, '100%', '', '3', 'center', '');
+	html_start_box($header_label, '100%', true, '3', 'center', '');
 
 	$gtsql = get_common_graph_templates($graph);
 
 	if (!empty($graph['local_graph_id'])) {
 		$graph_template_id = get_current_graph_template($graph['local_graph_id']);
-	}else{
+	} else {
 		$graph_template_id = 0;
 	}
 
@@ -1352,21 +1356,21 @@ function graph_edit() {
 
 	draw_edit_form(
 		array(
-			'config' => array(),
+			'config' => array('no_form_tag' => true),
 			'fields' => $form_array
-			)
-		);
+		)
+	);
 
-	html_end_box();
+	html_end_box(true, true);
 
 	/* only display the "inputs" area if we are using a graph template for this graph */
 	if (!empty($graph['graph_template_id'])) {
-		html_start_box(__('Supplemental Graph Template Data'), '100%', '', '3', 'center', '');
+		html_start_box(__('Supplemental Graph Template Data'), '100%', true, '3', 'center', '');
 
-		draw_nontemplated_fields_graph($graph['graph_template_id'], $graph, '|field|', '<strong>' . __('Graph Fields') . '</strong>', true, true, 0);
-		draw_nontemplated_fields_graph_item($graph['graph_template_id'], get_request_var('id'), '|field|_|id|', '<strong>' . __('Graph Item Fields') . '</strong>', true, $locked);
+		draw_nontemplated_fields_graph($graph['graph_template_id'], $graph, '|field|', __('Graph Fields'), true, true, 0);
+		draw_nontemplated_fields_graph_item($graph['graph_template_id'], get_request_var('id'), '|field|_|id|', __('Graph Item Fields'), true, $locked);
 
-		html_end_box();
+		html_end_box(true, true);
 	}
 
 	/* graph item list goes here */
@@ -1374,12 +1378,13 @@ function graph_edit() {
 		item();
 	}
 
+	$graph['src'] = htmlspecialchars($config['url_path'] . 'graph_json.php?local_graph_id=' . get_request_var('id') . '&rra_id=0&graph_start=' . (time()-86400) . '&graph_end=-300&v=' . mt_rand());
+
 	if (!isempty_request_var('id')) {
 		?>
 		<table style='width:100%;'>
 			<tr>
-				<td class="textInfo center" colspan="2">
-					<img <?php print ($graph['image_format_id'] == 3 ? "style='width:" . $graph['width'] . "px;height:" . $graph['height'] . "px;'":"");?> src="<?php print htmlspecialchars('graph_image.php?action=edit&disable_cache=true&local_graph_id=' . get_request_var('id') . '&rra_id=' . read_user_setting('default_rra_id') . '&v=' . mt_rand());?>" alt="">
+				<td id='graphLocation' class='textInfo center'>
 				</td>
 				<?php
 				if ((isset($_SESSION['graph_debug_mode'])) && (isset_request_var('id'))) {
@@ -1387,9 +1392,9 @@ function graph_edit() {
 					$graph_data_array['print_source'] = 1;
 					?>
 					<td>
-						<span class="textInfo"><?php print __('RRDTool Command:');?></span><br>
+						<span class='textInfo'><?php print __('RRDTool Command:');?></span><br>
 						<pre><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
-						<span class="textInfo"><?php print __('RRDTool Says:');?></span><br>
+						<span class='textInfo'><?php print __('RRDTool Says:');?></span><br>
 						<?php unset($graph_data_array['print_source']);?>
 						<pre><?php print @rrdtool_function_graph(get_request_var('id'), 1, $graph_data_array);?></pre>
 					</td>
@@ -1403,7 +1408,7 @@ function graph_edit() {
 	}
 
 	if (((isset_request_var('id')) || (isset_request_var('new'))) && (empty($graph['graph_template_id']))) {
-		html_start_box(__('Graph Configuration'), '100%', '', '3', 'center', '');
+		html_start_box(__('Graph Configuration'), '100%', true, '3', 'center', '');
 
 		$form_array = array();
 
@@ -1428,26 +1433,28 @@ function graph_edit() {
 			)
 		);
 
-		html_end_box();
+		html_end_box(true, true);
 	}
 
 	if ((isset_request_var('id')) || (isset_request_var('new'))) {
 		form_hidden_box('save_component_graph','1','');
 		form_hidden_box('save_component_input','1','');
-	}else{
+	} else {
 		form_hidden_box('save_component_graph_new','1','');
 	}
 
 	form_hidden_box('rrdtool_version', read_config_option('rrdtool_version'), '');
+
 	form_save_button('graphs.php');
 
 	//Now we need some javascript to make it dynamic
 	?>
 	<script type='text/javascript'>
 
-	var locked=<?php print ($locked ? 'true':'false');?>;
-
-	dynamic();
+	var locked         = <?php print ($locked ? 'true':'false');?>;
+	var imageSource    = '<?php print $graph['src'];?>';
+	var originalWidth  = null;
+	var originalHeight = null;
 
 	function dynamic() {
 		if ($('#scale_log_units').is(':checked')) {
@@ -1468,6 +1475,8 @@ function graph_edit() {
 	}
 
 	$(function() {
+		dynamic();
+
 		$('#unlockid').click(function(event) {
 			event.preventDefault;
 
@@ -1480,18 +1489,50 @@ function graph_edit() {
 			});
 		});
 
+		$.getJSON(imageSource, function(data) {
+			$('#graphLocation').html("<img class='cactiGraphImage' src='data:image/"+data.type+";base64,"+data.image+"' graph_start='"+data.graph_start+"' graph_end='"+data.graph_end+"' graph_left='"+data.graph_left+"' graph_top='"+data.graph_top+"' graph_width='"+data.graph_width+"' graph_height='"+data.graph_height+"' width='"+data.image_width+"' height='"+data.image_height+"' image_width='"+data.image_width+"' image_height='"+data.image_height+"' value_min='"+data.value_min+"' value_max='"+data.value_max+"'>");
+			$(window).trigger('resize');
+		});
+
 		$('#lockid').click(function(event) {
 			event.preventDefault;
 
 			loadPageNoHeader('graphs.php?action=lock&header=false&id='+$('#local_graph_id').val());
 		});
+
+		$(window).resize(function() {
+			imageWidth    = $('.cactiGraphImage').width();
+			imageHeight   = $('.cactiGraphImage').height();
+			aspectRatio   = imageWidth/imageHeight;
+
+			if (imageWidth > 0 && originalWidth == null) {
+				originalWidth = imageWidth;
+				originalHeight = imageHeight;
+			}
+
+			$('.cactiGraphImage').hide();
+
+			mainSize      = $('#main').width();
+
+			if (imageWidth > mainSize || mainSize < originalWidth) {
+				newWidth    = mainSize - 40;
+				aspectRatio = imageWidth / imageHeight;
+				imageWidth  = newWidth;
+				imageHeight = newWidth / aspectRatio;
+				$('.cactiGraphImage').css({ width: imageWidth, height: imageHeight });
+			} else if (mainSize > originalWidth) {
+				$('.cactiGraphImage').css({ width: originalWidth, height: originalHeight });
+			}
+
+			$('.cactiGraphImage').show();
+		}).trigger('resize');
 	});
 
 	if (locked) {
 		$('input, select').not('input[value="<?php print __('Cancel');?>"]').prop('disabled', true);
 		if ($('#submit').button === 'function') {
 			$('#submit').button('disable');
-		}else{
+		} else {
 			$('#submit').prop('disabled', true);
 		}
 		$('#host_id_wrap').addClass('ui-selectmenu-disabled ui-state-disabled');
@@ -1550,7 +1591,7 @@ function graph_management() {
 
 	if (get_request_var('rows') == -1) {
 		$rows = read_config_option('num_rows_table');
-	}else{
+	} else {
 		$rows = get_request_var('rows');
 	}
 
@@ -1592,7 +1633,7 @@ function graph_management() {
 
 	if (read_config_option('grds_creation_method') == 1) {
 		$add_url = htmlspecialchars('graphs.php?action=graph_edit&host_id=' . get_request_var('host_id'));
-	}else{
+	} else {
 		$add_url = '';
 	}
 
@@ -1615,9 +1656,9 @@ function graph_management() {
 							<?php
 							if (get_request_var('host_id') == 0) {
 								$templates = get_allowed_graph_templates_normalized('gl.host_id=0');
-							}elseif (get_request_var('host_id') > 0) {
+							} elseif (get_request_var('host_id') > 0) {
 								$templates = get_allowed_graph_templates_normalized('gl.host_id=' . get_filter_request_var('host_id'));
-							}else{
+							} else {
 								$templates = get_allowed_graph_templates_normalized();
 							}
 
@@ -1679,21 +1720,21 @@ function graph_management() {
 
 	if (get_request_var('host_id') == '-1') {
 		/* Show all items */
-	}elseif (isempty_request_var('host_id')) {
+	} elseif (isempty_request_var('host_id')) {
 		$sql_where .= (strlen($sql_where) ? ' AND ':'WHERE ') . ' gl.host_id=0';
-	}elseif (!isempty_request_var('host_id')) {
+	} elseif (!isempty_request_var('host_id')) {
 		$sql_where .= (strlen($sql_where) ? ' AND ':'WHERE ') . ' gl.host_id=' . get_request_var('host_id');
 	}
 
 	if (get_request_var('template_id') == '-1') {
 		/* Show all items */
-	}elseif (get_request_var('template_id') == '0') {
+	} elseif (get_request_var('template_id') == '0') {
 		$sql_where .= (strlen($sql_where) ? ' AND ':'WHERE ') . ' gtg.graph_template_id=0';
-	}elseif (!isempty_request_var('template_id')) {
+	} elseif (!isempty_request_var('template_id')) {
 		$parts = explode('_', get_request_var('template_id'));
 		if ($parts[0] == 'cg') {
 			$sql_where .= (strlen($sql_where) ? ' AND ':'WHERE ') . ' gl.graph_template_id=' . $parts[1];
-		}else{
+		} else {
 			$sql_where .= (strlen($sql_where) ? ' AND ':'WHERE ') . ' gl.snmp_query_graph_id=' . $parts[1];
 		}
 	}
@@ -1762,7 +1803,7 @@ function graph_management() {
 			form_checkbox_cell($graph['title_cache'], $graph['local_graph_id']);
 			form_end_row();
 		}
-	}else{
+	} else {
 		print "<tr class='tableRow'><td colspan='5'><em>" . __('No Graphs Found') . "</em></td></tr>";
 	}
 
