@@ -26,10 +26,26 @@
    !!! IMPORTANT !!!
 
    The following defaults are not to be altered.  Please refer to
-   include/config.php for user configurable database settings.
+   include/config.php for user configurable settings.
 
 */
 
+/* load cacti version from file */
+$cacti_version_file = dirname(__FILE__) . '/cacti_version';
+
+if (! file_exists($cacti_version_file)) {
+	die ('ERROR: failed to find cacti version file');
+}
+
+$cacti_version = file_get_contents($cacti_version_file, false);
+if ($cacti_version === false) {
+	die ('ERROR: failed to load cacti version file');
+}
+$cacti_version = trim($cacti_version);
+
+/* define cacti version */
+define('CACTI_VERSION', $cacti_version);
+
 /* Default database settings*/
 $database_type = 'mysql';
 $database_default = 'cacti';
@@ -56,14 +72,6 @@ if (isset($config['cacti_version'])) {
 	exit;
 }
 
-/* display ALL errors,
- * but suppress deprecated warnings as a workaround until 088 */
-if (defined('E_DEPRECATED')) {
-	error_reporting(E_ALL ^ E_DEPRECATED);
-}else{
-	error_reporting(E_ALL);
-}
-
 /* set the local for international users */
 setlocale(LC_CTYPE, 'en_US.UTF-8');
 
@@ -106,12 +114,12 @@ $config['php_snmp_support'] = function_exists('snmpget');
 /* Set the poller_id */
 if (isset($poller_id)) {
 	$config['poller_id'] = $poller_id;
-}else{
+} else {
 	$config['poller_id'] = 1;
 }
 
 /* check for an empty database port */
-if ($database_port == '') {
+if (empty($database_port)) {
 	$database_port = '3306';
 }
 
@@ -126,7 +134,7 @@ define('URL_PATH', $url_path);
 if ($config['cacti_server_os'] == 'win32') {
 	$config['base_path']    = str_replace("\\", "/", substr(dirname(__FILE__),0,-8));
 	$config['library_path'] = $config['base_path'] . '/lib';
-}else{
+} else {
 	$config['base_path']    = preg_replace("/(.*)[\/]include/", "\\1", dirname(__FILE__));
 	$config['library_path'] = preg_replace("/(.*[\/])include/", "\\1lib", dirname(__FILE__));
 }
@@ -136,13 +144,13 @@ $config['rra_path'] = $config['base_path'] . '/rra';
 /* for multiple pollers, we need to know this location */
 if (!isset($scripts_path)) {
 	$config['scripts_path'] = $config['base_path'] . '/scripts';
-}else{
+} else {
 	$config['scripts_path'] = $scripts_path;
 }
 
 if (!isset($resource_path)) {
 	$config['resource_path'] = $config['base_path'] . '/resource';
-}else{
+} else {
 	$config['resource_path'] = $resource_path;
 }
 
@@ -171,14 +179,11 @@ include_once($config['include_path'] . '/global_constants.php');
 
 $filename = get_current_page();
 
+$config['is_web'] = true;
 if ((isset($no_http_headers) && $no_http_headers == true) || in_array($filename, $no_http_header_files, true)) {
-	$is_web = false;
-}else{
-	$is_web = true;
+	$config['is_web'] = false;
 }
 
-$config['is_web'] = $is_web;
-
 /* set poller mode */
 global $local_db_cnn_id, $remote_db_cnn_id;
 
@@ -204,15 +209,15 @@ if ($config['poller_id'] > 1 || isset($rdatabase_hostname)) {
 		$database_ssl       = $rdatabase_ssl;
 
 		$config['connection'] = 'online';
-	}else{
+	} else {
 		$config['connection'] = 'offline';
 	}
 } elseif (!db_connect_real($database_hostname, $database_username, $database_password, $database_default, $database_type, $database_port, $database_ssl)) {
-	print $is_web ? '<p>':'';
+	print $config['is_web'] ? '<p>':'';
 	print 'FATAL: Connection to Cacti database failed. Please insure the database is running and your credentials in config.php are valid.';
-	print $is_web ? '</p>':'';
+	print $config['is_web'] ? '</p>':'';
 	exit;
-}else{
+} else {
 	/* gather the existing cactidb version */
 	$config['cacti_db_version'] = db_fetch_cell('SELECT cacti FROM version LIMIT 1');
 }
@@ -226,7 +231,7 @@ if ($config['poller_id'] > 1 && $config['connection'] == 'online') {
 
 if (isset($cacti_db_session) && $cacti_db_session && db_table_exists('sessions')) {
 	include(dirname(__FILE__) . '/session.php');
-}else{
+} else {
 	$cacti_db_session = false;
 }
 
@@ -234,9 +239,9 @@ set_error_handler('CactiErrorHandler');
 register_shutdown_function('CactiShutdownHandler');
 
 /* verify the cacti database is initialized before moving past here */
-db_cacti_initialized($is_web);
+db_cacti_initialized($config['is_web']);
 
-if ($is_web) {
+if ($config['is_web']) {
 	/* set the maximum post size */
 	ini_set('post_max_size', '8M');
 	ini_set('max_input_vars', '5000');
@@ -274,7 +279,7 @@ if ($is_web) {
 	/* make sure to start only only Cacti session at a time */
 	if (!isset($_SESSION['cacti_cwd'])) {
 		$_SESSION['cacti_cwd'] = $config['base_path'];
-	}else{
+	} else {
 		if ($_SESSION['cacti_cwd'] != $config['base_path']) {
 			session_unset();
 			session_destroy();
@@ -312,12 +317,13 @@ include_once($config['include_path'] . '/global_languages.php');
 include_once($config['library_path'] . '/auth.php');
 include_once($config['library_path'] . '/plugins.php');
 include_once($config['include_path'] . '/plugins.php');
+include_once($config['library_path'] . '/html_utility.php');
 include_once($config['include_path'] . '/global_arrays.php');
 include_once($config['include_path'] . '/global_settings.php');
 include_once($config['include_path'] . '/global_form.php');
 include_once($config['library_path'] . '/html.php');
 include_once($config['library_path'] . '/html_form.php');
-include_once($config['library_path'] . '/html_utility.php');
+include_once($config['library_path'] . '/html_filter.php');
 include_once($config['library_path'] . '/html_validate.php');
 include_once($config['library_path'] . '/variables.php');
 include_once($config['library_path'] . '/mib_cache.php');
@@ -326,7 +332,7 @@ include_once($config['library_path'] . '/aggregate.php');
 include_once($config['library_path'] . '/api_automation.php');
 
 /* cross site request forgery library */
-if ($is_web) {
+if ($config['is_web']) {
 	function csrf_startup() {
 		global $config;
 		csrf_conf('rewrite-js', $config['url_path'] . 'include/csrf/csrf-magic.js');
@@ -347,6 +353,6 @@ if ($is_web) {
 
 api_plugin_hook('config_insert');
 
-/* current cacti version */
-$config['cacti_version'] = '1.1.5';
+/* set config cacti_version for plugins */
+$config['cacti_version'] = CACTI_VERSION;;
 
