@@ -126,7 +126,7 @@ function realtimeGrapher() {
 			Pace.ignore(function() {
 				position = $('#wrapper_'+local_graph_id).find('img').position();
 
-				$.get(urlPath+'graph_realtime.php?action=countdown&top='+parseInt(position.top)+'&left='+parseInt(position.left)+(isThumb ? '&graph_nolegend=true':'')+'&graph_end=0&graph_start=-'+graph_start+'&local_graph_id='+local_graph_id+'&ds_step='+ds_step+'#count='+count, function(data) {
+				$.get(urlPath+'graph_realtime.php?action=countdown&top='+parseInt(position.top)+'&left='+parseInt(position.left)+(isThumb ? '&graph_nolegend=true':'')+'&graph_end=0&graph_start=-'+graph_start+'&local_graph_id='+local_graph_id+'&ds_step='+ds_step+'&count='+count, function(data) {
 					results = $.parseJSON(data);
 
 					$('#graph_'+results.local_graph_id).prop('src', 'data:image/png;base64,'+results.data).change();
