@@ -21,6 +21,7 @@
  | http://www.cacti.net/                                                   |
  +-------------------------------------------------------------------------+
 */
+error_reporting(E_ALL);
 
 define('IN_CACTI_INSTALL', 1);
 
@@ -41,38 +42,31 @@ if (get_request_var('action') == 'testdb') {
 /* allow the upgrade script to run for as long as it needs to */
 ini_set('max_execution_time', '0');
 
-$cacti_versions = array('0.8', '0.8.1', '0.8.2', '0.8.2a', '0.8.3', '0.8.3a', '0.8.4', '0.8.5', '0.8.5a',
-	'0.8.6', '0.8.6a', '0.8.6b', '0.8.6c', '0.8.6d', '0.8.6e', '0.8.6f', '0.8.6g', '0.8.6h', '0.8.6i', '0.8.6j', '0.8.6k',
-	'0.8.7', '0.8.7a', '0.8.7b', '0.8.7c', '0.8.7d', '0.8.7e', '0.8.7f', '0.8.7g', '0.8.7h', '0.8.7i',
-	'0.8.8', '0.8.8a', '0.8.8b', '0.8.8c', '0.8.8d', '0.8.8e', '0.8.8f', '0.8.8g', '0.8.8h', '1.0.0',
-	'1.0.1', '1.0.2', '1.0.3', '1.0.4', '1.0.5', '1.0.6', '1.1.0', '1.1.1', '1.1.2', '1.1.3', '1.1.4');
+$cacti_versions = array_keys($cacti_version_codes);
 
 $old_cacti_version = db_fetch_cell('SELECT cacti FROM version');
 
-/* try to find current (old) version in the array */
-$old_version_index = array_search($old_cacti_version, $cacti_versions);
-
 /* do a version check */
-if ($old_cacti_version == $config['cacti_version']) {
+if ($old_cacti_version == CACTI_VERSION) {
 	print '<p style="font-family: Verdana, Arial; font-size: 16px; font-weight: bold; color: red;">' . __('Error') . '</p>
 		<p style="font-family: Verdana, Arial; font-size: 12px;">' 
 		. __('This installation is already up-to-date. Click <a href="%s">here</a> to use Cacti.', '../index.php') . '</p>';
 	exit;
-}elseif (preg_match('/^0\.6/', $old_cacti_version)) {
+} elseif (preg_match('/^0\.6/', $old_cacti_version)) {
 	print '<p style="font-family: Verdana, Arial; font-size: 16px; font-weight: bold; color: red;">' . __('Error') . '</p>
 		<p style="font-family: Verdana, Arial; font-size: 12px;">' 
-		. __('You are attempting to install Cacti %s onto a 0.6.x database. To continue, you must create a new database, import "cacti.sql" into it, and update "include/config.php" to point to the new database.', $config['cacti_version']) . '</p>';
+		. __('You are attempting to install Cacti %s onto a 0.6.x database. To continue, you must create a new database, import "cacti.sql" into it, and update "include/config.php" to point to the new database.', CACTI_VERSION) . '</p>';
 	exit;
-}elseif (empty($old_cacti_version)) {
+} elseif (empty($old_cacti_version)) {
 	print '<p style="font-family: Verdana, Arial; font-size: 16px; font-weight: bold; color: red;">' . __('Error') . '</p>
 		<p style="font-family: Verdana, Arial; font-size: 12px;">' 
 		. __("You have created a new database, but have not yet imported the 'cacti.sql' file. At the command line, execute the following to continue:</p><p><pre>mysql -u %s -p %s < cacti.sql</pre></p><p>This error may also be generated if the cacti database user does not have correct permissions on the Cacti database. Please ensure that the Cacti database user has the ability to SELECT, INSERT, DELETE, UPDATE, CREATE, ALTER, DROP, INDEX on the Cacti database.", $database_username, $database_default) . '</p>';
 
-	print '<p>' . __("In Cacti %s, you must also import MySQL TimeZone information into MySQL and grant the Cacti user SELECT access to the mysql.time_zone_name table", $config['cacti_version']) . '</p>';
+	print '<p>' . __("In Cacti %s, you must also import MySQL TimeZone information into MySQL and grant the Cacti user SELECT access to the mysql.time_zone_name table", CACTI_VERSION) . '</p>';
 
 	if ($config['cacti_server_os'] == 'unix') {
 		print '<p>' . __("On Linux/UNIX, do the following:") . '</p><p><pre>' . __("mysql_tzinfo_to_sql /usr/share/zoneinfo | mysql -u root -p mysql") . "\n";
-	}else{
+	} else {
 		print '<p>' . __("On Windows, you must follow the instructions here <a target='_blank' href='https://dev.mysql.com/downloads/timezones.html'>Time zone description table</a>.  Once that is complete, you can issue the following command to grant the Cacti user access to the tables:") . '</p><p><pre>';
 	}
 	print __("GRANT SELECT ON mysql.time_zone_name to '%s'@'localhost' IDENTIFIED BY '%s'", $database_username, $database_password) . '</pre></p>';
@@ -83,16 +77,16 @@ if ($old_cacti_version == $config['cacti_version']) {
 /* default value for this variable */
 if (isset_request_var('install_type')) {
 	$_SESSION['sess_install_type'] = get_filter_request_var('install_type');
-}elseif (isset($_SESSION['sess_install_type'])) {
+} elseif (isset($_SESSION['sess_install_type'])) {
 	set_request_var('install_type', $_SESSION['sess_install_type']);
-}else{
+} else {
 	set_request_var('install_type', '0');
 }
 
 /* defaults for the install type dropdown */
 if ($old_cacti_version == 'new_install') {
 	$default_install_type = '1';
-}else{
+} else {
 	$default_install_type = '3';
 }
 
@@ -119,10 +113,10 @@ if (isset_request_var('step') && get_filter_request_var('step') > 0) {
 		if (get_filter_request_var('install_type') == '1') {
 			/* install - New Primary Server */
 			$step = 4;
-		}elseif (get_filter_request_var('install_type') == '2') {
+		} elseif (get_filter_request_var('install_type') == '2') {
 			/* install - New Remote Poller */
 			$step = 4;
-		}elseif (get_filter_request_var('install_type') == '3') {
+		} elseif (get_filter_request_var('install_type') == '3') {
 			/* install/upgrade - if user chooses "Upgrade" send to upgrade */
 			$step = 8;
 		}
@@ -141,7 +135,7 @@ if (isset_request_var('step') && get_filter_request_var('step') > 0) {
 		if (get_request_var('install_type') != 2) {
 			/* settings-install - send to template-import */
 			$step = 6;
-		}else{
+		} else {
 			/* remote pollers are done, no template import */
 			$step = 7;
 		}
@@ -157,11 +151,11 @@ if (isset_request_var('step') && get_filter_request_var('step') > 0) {
 		break;
 	case '8':
 		$previous_step = 8;
-		/* upgrade - if user upgrades send to settingscheck */
-		if ($old_version_index <= array_search('0.8.5a', $cacti_versions)) {
-			/* upgrade - if user runs old version send to upgrade-oldversion*/
+		/* upgrade - if user upgrades send to settings check */
+		if (version_compare($old_cacti_version, '0.8.5a', '<=')) {
+			/* upgrade - if user runs old version send to upgrade-oldversion */
 			$step = 9;
-		}else{
+		} else {
 			$step = 7;
 		}
 		break;
@@ -210,7 +204,7 @@ if ($step == '7') {
 			$avail        = 'snmp';
 			$ip           = 'localhost';
 			$description  = "Local Windows Machine";
-		}else{
+		} else {
 			$hash = '2d3e47f416738c2d22c87c40218cc55e';
 			$version      = 0;
 			$community    = 'public';
@@ -248,7 +242,7 @@ if ($step == '7') {
 					}
 				}
 			}
-		}else{
+		} else {
 			cacti_log('WARNING: Device Template for your Operating System Not Found.  You will need to import Device Templates or Cacti Packages to monitor your Cacti server.');
 		}
 	}
@@ -260,12 +254,12 @@ if ($step == '7') {
 	
 		/* change cacti version */
 		db_execute('DELETE FROM version', true, $local_db_cnn_id);
-		db_execute("INSERT INTO version (cacti) VALUES ('" . $config["cacti_version"] . "')", true, $local_db_cnn_id);
+		db_execute("INSERT INTO version (cacti) VALUES ('" . CACTI_VERSION . "')", true, $local_db_cnn_id);
 
 		/* make the poller and poller_output_boost InnoDB */
 		db_execute('ALTER TABLE poller_output ENGINE=InnoDB');
 		db_execute('ALTER TABLE poller_output_boost ENGINE=InnoDB');
-	}else{
+	} else {
 		/* pre-fill poller cache with initial data on a new install only */
 		if ($old_cacti_version == 'new_install') {
 			/* just in case we have hard drive graphs to deal with */
@@ -287,7 +281,7 @@ if ($step == '7') {
 	
 		/* change cacti version */
 		db_execute('DELETE FROM version');
-		db_execute("INSERT INTO version (cacti) VALUES ('" . $config['cacti_version'] . "')");
+		db_execute("INSERT INTO version (cacti) VALUES ('" . CACTI_VERSION . "')");
 	}
 
 	/* clear session */
@@ -301,154 +295,34 @@ if ($step == '7') {
 	exit;
 
 /* upgrade */
-}elseif (($step == '8') && (get_filter_request_var('install_type') == '3')) {
-	/* if the version is not found, die */
-	if (!is_int($old_version_index)) {
+} elseif (($step == '8') && (get_filter_request_var('install_type') == '3')) {
+
+	// if the version is not found, die
+	if (! array_key_exists($old_cacti_version, $cacti_version_codes)) {
 		print "	<p style='font-family: Verdana, Arial; font-size: 16px; font-weight: bold; color: red;'>" . __('Error') . "</p>
 			<p style='font-family: Verdana, Arial; font-size: 12px;'>"
-			. __('Invalid Cacti version <strong>%1$s</strong>, cannot upgrade to <strong>%2$s</strong>', $old_cacti_version, $config['cacti_version']) . "</p>";
+			. __('Invalid Cacti version <strong>%1$s</strong>, cannot upgrade to <strong>%2$s</strong>', $old_cacti_version, CACTI_VERSION) . "</p>";
 		exit;
 	}
 
-	/* loop from the old version to the current, performing updates for each version in between */
-	for ($i=($old_version_index+1); $i<count($cacti_versions); $i++) {
-		$upgrade_version = $cacti_versions[$i];
-		if ($cacti_versions[$i] == '0.8.1') {
-			include ('0_8_to_0_8_1.php');
-			upgrade_to_0_8_1();
-		}elseif ($cacti_versions[$i] == '0.8.2') {
-			include ('0_8_1_to_0_8_2.php');
-			upgrade_to_0_8_2();
-		}elseif ($cacti_versions[$i] == '0.8.2a') {
-			include ('0_8_2_to_0_8_2a.php');
-			upgrade_to_0_8_2a();
-		}elseif ($cacti_versions[$i] == '0.8.3') {
-			include ('0_8_2a_to_0_8_3.php');
-			include_once('../lib/utility.php');
-			upgrade_to_0_8_3();
-		}elseif ($cacti_versions[$i] == '0.8.4') {
-			include ('0_8_3_to_0_8_4.php');
-			upgrade_to_0_8_4();
-		}elseif ($cacti_versions[$i] == '0.8.5') {
-			include ('0_8_4_to_0_8_5.php');
-			upgrade_to_0_8_5();
-		}elseif ($cacti_versions[$i] == '0.8.6') {
-			include ('0_8_5a_to_0_8_6.php');
-			upgrade_to_0_8_6();
-		}elseif ($cacti_versions[$i] == '0.8.6a') {
-			include ('0_8_6_to_0_8_6a.php');
-			upgrade_to_0_8_6a();
-		}elseif ($cacti_versions[$i] == '0.8.6d') {
-			include ('0_8_6c_to_0_8_6d.php');
-			upgrade_to_0_8_6d();
-		}elseif ($cacti_versions[$i] == '0.8.6e') {
-			include ('0_8_6d_to_0_8_6e.php');
-			upgrade_to_0_8_6e();
-		}elseif ($cacti_versions[$i] == '0.8.6g') {
-			include ('0_8_6f_to_0_8_6g.php');
-			upgrade_to_0_8_6g();
-		}elseif ($cacti_versions[$i] == '0.8.6h') {
-			include ('0_8_6g_to_0_8_6h.php');
-			upgrade_to_0_8_6h();
-		}elseif ($cacti_versions[$i] == '0.8.6i') {
-			include ('0_8_6h_to_0_8_6i.php');
-			upgrade_to_0_8_6i();
-		}elseif ($cacti_versions[$i] == '0.8.7') {
-			include ('0_8_6j_to_0_8_7.php');
-			upgrade_to_0_8_7();
-		}elseif ($cacti_versions[$i] == '0.8.7a') {
-			include ('0_8_7_to_0_8_7a.php');
-			upgrade_to_0_8_7a();
-		}elseif ($cacti_versions[$i] == '0.8.7b') {
-			include ('0_8_7a_to_0_8_7b.php');
-			upgrade_to_0_8_7b();
-		}elseif ($cacti_versions[$i] == '0.8.7c') {
-			include ('0_8_7b_to_0_8_7c.php');
-			upgrade_to_0_8_7c();
-		}elseif ($cacti_versions[$i] == '0.8.7d') {
-			include ('0_8_7c_to_0_8_7d.php');
-			upgrade_to_0_8_7d();
-		}elseif ($cacti_versions[$i] == '0.8.7e') {
-			include ('0_8_7d_to_0_8_7e.php');
-			upgrade_to_0_8_7e();
-		}elseif ($cacti_versions[$i] == '0.8.7f') {
-			include ('0_8_7e_to_0_8_7f.php');
-			upgrade_to_0_8_7f();
-		}elseif ($cacti_versions[$i] == '0.8.7g') {
-			include ('0_8_7f_to_0_8_7g.php');
-			upgrade_to_0_8_7g();
-		}elseif ($cacti_versions[$i] == '0.8.7h') {
-			include ('0_8_7g_to_0_8_7h.php');
-			upgrade_to_0_8_7h();
-		}elseif ($cacti_versions[$i] == '0.8.7i') {
-			include ('0_8_7h_to_0_8_7i.php');
-			upgrade_to_0_8_7i();
-		}elseif ($cacti_versions[$i] == '0.8.8') {
-			include ('0_8_7i_to_0_8_8.php');
-			upgrade_to_0_8_8();
-		}elseif ($cacti_versions[$i] == '0.8.8a') {
-			include ('0_8_8_to_0_8_8a.php');
-			upgrade_to_0_8_8a();
-		}elseif ($cacti_versions[$i] == '0.8.8b') {
-			include ('0_8_8a_to_0_8_8b.php');
-			upgrade_to_0_8_8b();
-		}elseif ($cacti_versions[$i] == '0.8.8c') {
-			include ('0_8_8b_to_0_8_8c.php');
-			upgrade_to_0_8_8c();
-		}elseif ($cacti_versions[$i] == '0.8.8d') {
-			include ('0_8_8c_to_0_8_8d.php');
-			upgrade_to_0_8_8d();
-		}elseif ($cacti_versions[$i] == '0.8.8e') {
-			include ('0_8_8d_to_0_8_8e.php');
-			upgrade_to_0_8_8e();
-		}elseif ($cacti_versions[$i] == '0.8.8f') {
-			include ('0_8_8e_to_0_8_8f.php');
-			upgrade_to_0_8_8f();
-		}elseif ($cacti_versions[$i] == '0.8.8g') {
-			include ('0_8_8f_to_0_8_8g.php');
-			upgrade_to_0_8_8g();
-		}elseif ($cacti_versions[$i] == '0.8.8h') {
-			include ('0_8_8g_to_0_8_8h.php');
-			upgrade_to_0_8_8h();
-		}elseif ($cacti_versions[$i] == '1.0.0') {
-			include ('0_8_8h_to_1_0_0.php');
-			upgrade_to_1_0_0();
-		}elseif ($cacti_versions[$i] == '1.0.1') {
-			include ('1_0_0_to_1_0_1.php');
-			upgrade_to_1_0_1();
-		}elseif ($cacti_versions[$i] == '1.0.2') {
-			include ('1_0_1_to_1_0_2.php');
-			upgrade_to_1_0_2();
-		}elseif ($cacti_versions[$i] == '1.0.3') {
-			include ('1_0_2_to_1_0_3.php');
-			upgrade_to_1_0_3();
-		}elseif ($cacti_versions[$i] == '1.0.4') {
-			include ('1_0_3_to_1_0_4.php');
-			upgrade_to_1_0_4();
-		}elseif ($cacti_versions[$i] == '1.0.5') {
-			include ('1_0_4_to_1_0_5.php');
-			upgrade_to_1_0_5();
-		}elseif ($cacti_versions[$i] == '1.0.6') {
-			include ('1_0_5_to_1_0_6.php');
-			upgrade_to_1_0_6();
-		}elseif ($cacti_versions[$i] == '1.1.0') {
-			include ('1_0_6_to_1_1_0.php');
-			upgrade_to_1_1_0();
-		}elseif ($cacti_versions[$i] == '1.1.1') {
-			include ('1_1_0_to_1_1_1.php');
-			upgrade_to_1_1_1();
-		}elseif ($cacti_versions[$i] == '1.1.2') {
-			include ('1_1_1_to_1_1_2.php');
-			upgrade_to_1_1_2();
-		}elseif ($cacti_versions[$i] == '1.1.3') {
-			include ('1_1_2_to_1_1_3.php');
-			upgrade_to_1_1_3();
-		}elseif ($cacti_versions[$i] == '1.1.4') {
-			include ('1_1_3_to_1_1_4.php');
-			upgrade_to_1_1_4();
-		}elseif ($cacti_versions[$i] == '1.1.5') {
-			include ('1_1_4_to_1_1_5.php');
-			upgrade_to_1_1_5();
+	// loop through versions from old version to the current, performing updates for each version in the chain
+	foreach ($cacti_version_codes as $cacti_version => $hash_code)  {
+
+		// skip versions old than the database version
+		if (version_compare($old_cacti_version, $cacti_version, '>=')) {
+			continue;
+		}
+
+		// construct version upgrade include path
+		$upgrade_file = dirname(__FILE__) . '/upgrades/' . str_replace('.', '_', $cacti_version) . '.php';
+		$upgrade_function = 'upgrade_to_' . str_replace('.', '_', $cacti_version);
+
+		// check for upgrade version file, then include, check for function and execute
+		if (file_exists($upgrade_file)) {
+			include($upgrade_file);
+			if (function_exists($upgrade_function)) {
+				call_user_func($upgrade_function);
+			}
 		}
 	}
 
@@ -561,7 +435,7 @@ $enabled = '1';
 						<span><input type='checkbox' id='accept' name='accept'></span><span><label for='accept'>Accept GPL License Agreement</label></span><br><br>
 					<?php 	
 					/* checkdependencies */
-					}elseif ($step == '2') { 
+					} elseif ($step == '2') { 
 						$enabled = '1';
 
 						print '<h2>' . __('Pre-installation Checks') .'</h2>';
@@ -573,7 +447,7 @@ $enabled = '1';
 								print '<p class="textError"><strong>' . __('ERROR:') . '</strong> ' .  __('Your MySQL TimeZone database is not populated.  Please populate this database before proceeding.') . '</p>';
 								$enabled = '0';
 							}
-						}else{
+						} else {
 							print '<p class="textError"><strong>' . __('ERROR:') . '</strong> ' .  __('Your Cacti database login account does not have access to the MySQL TimeZone database.  Please provide the Cacti database account "select" access to the "time_zone_name" table in the "mysql" database, and populate MySQL\'s TimeZone information before proceeding.') . '</p>';
 							$enabled = '0';
 						}
@@ -612,7 +486,7 @@ $enabled = '1';
 								array('name' => 'gd',        'installed' => false),
 								array('name' => 'zlib',      'installed' => false)
 							);
-						}elseif (version_compare(PHP_VERSION, '5.4.5') < 0) {
+						} elseif (version_compare(PHP_VERSION, '5.4.5') < 0) {
 							$extensions = array( 
 								array('name' => 'session',   'installed' => false),
 								array('name' => 'sockets',   'installed' => false),
@@ -627,7 +501,7 @@ $enabled = '1';
 								array('name' => 'gd',        'installed' => false),
 								array('name' => 'zlib',      'installed' => false)
 							);
-						}else{
+						} else {
 							$extensions = array( 
 								array('name' => 'com_dotnet','installed' => false),
 								array('name' => 'session',   'installed' => false),
@@ -682,7 +556,7 @@ $enabled = '1';
 						utilities_get_mysql_recommendations();
 						html_end_box(false);
 					/* install/upgrade */
-					}elseif ($step == '3') {
+					} elseif ($step == '3') {
 						print '<h2>' . __('Installation Type') . '</h2>';
 
 						print '<h4>' . __('Please select the type of installation') . '</h4>';
@@ -703,7 +577,7 @@ $enabled = '1';
 									<option value="3"' . (($default_install_type == '3') ? ' selected' : '') . '>' . __('Upgrade Previous Cacti') . '</option>
 								</select>
 							</p>';
-						}else{
+						} else {
 							print '<p>
 								<select id="install_type" name="install_type">
 									<option value="1"' . (($default_install_type == '1') ? ' selected' : '') . '>' . __('New Primary Server') . '</option>
@@ -735,7 +609,7 @@ $enabled = '1';
 
 						if (is_writable($config['base_path'] . '/include/config.php')) {
 							$good_write = true;
-						}else{
+						} else {
 							$good_write = false;
 						}
 
@@ -744,7 +618,7 @@ $enabled = '1';
 							isset($rdatabase_hostname) &&
 							isset($rdatabase_port)) {
 							$remote_good = true;
-						}else{
+						} else {
 							$remote_good = false;
 						}
 
@@ -757,7 +631,7 @@ $enabled = '1';
 								. __('Port: <b>%s</b>', $rdatabase_port) . '<br>'
 								. __('Server Operating System Type: <b>%s</b>', $config['cacti_server_os']) . '<br>'
 							. '</p>';
-						}else{
+						} else {
 							print '<h4>' . __('Remote Poller Cacti database connection information') . '</h4>';
 
 							if (!$good_write) {
@@ -823,7 +697,7 @@ $enabled = '1';
 									$('#test').button().show();
 									if (test_good) {
 										$('#next').prop('disabled', false).button('enable');
-									}else{
+									} else {
 										$('#next').button('disable');
 									}
 									<?php } else { ?>
@@ -860,7 +734,7 @@ $enabled = '1';
 						</script>
 						<?php
 				 	/* settingscheck */
-					}elseif ($step == '4') {
+					} elseif ($step == '4') {
 						print '<h2>' . __('Critical Binary Locations and Versions') . '</h2>';
 
 						print '<p>' . __('Make sure all of these values are correct before continuing.') . '</p>';						
@@ -881,7 +755,7 @@ $enabled = '1';
 
 								if (!empty($array['friendly_name'])) {
 									print ': ' . $array['description'];
-								}else{
+								} else {
 									print '<strong>' . $array['description'] . '</strong>';
 								}
 
@@ -906,7 +780,7 @@ $enabled = '1';
 						}
 						
 				 	/* settings-install */
-					}elseif ($step == '5') { 
+					} elseif ($step == '5') { 
 						include_once('../lib/data_query.php');
 						include_once('../lib/utility.php');
 
@@ -927,7 +801,7 @@ $enabled = '1';
 
 						if (get_request_var('install_type') == 1) {
 							print '<p>' . __('After the install is complete, you can make some of these directories read only to increase security.') . '</p>';						
-						}else{
+						} else {
 							print '<p>' . __('These directories will be required to stay read writable after the install so that the Cacti remote synchronization process can update them as the Main Cacti Web Site changes') . '</p>';
 						}
 
@@ -978,7 +852,7 @@ $enabled = '1';
 									$writable = false;
 								}
 							}
-						}else{
+						} else {
 							print '<p><strong>' . __('Required Writable after Install Complete') . '</strong></p>';
 							foreach($remote_paths as $path) {
 								if (is_writable($path)) {
@@ -994,7 +868,7 @@ $enabled = '1';
 						if (($config['cacti_server_os'] == 'unix') && isset($writable)) {
 							print '<p>' . __('Make sure your webserver has read and write access to the entire folder structure.<br> Example: chown -R apache.apache %s/resource/', $config['base_path']) . '</p>';
 							print '<p>' . __('For SELINUX-users make sure that you have the correct permissions or set \'setenforce 0\' temporarily.') . '</p><br>';
-						}elseif (($config['cacti_server_os'] == 'win32') && isset($writable)){
+						} elseif (($config['cacti_server_os'] == 'win32') && isset($writable)){
 							print __('Check Permissions');
 						}else {
 							print '<font color="#008000">' . __('All folders are writable') . '</font><br><br>';
@@ -1006,7 +880,7 @@ $enabled = '1';
 							print __('NOTE:') . '</font></strong> ' . __('If you are installing packages, once the packages are installed, you should change the scripts directory back to read only as this presents some exposure to the web site.');
 
 							print '</p>';
-						}else{
+						} else {
 							print '<p><strong><font color="#FF0000">';
 
 							print __('NOTE:') . '</font></strong> ' . __('For remote pollers, it is critical that
@@ -1018,7 +892,7 @@ $enabled = '1';
 						}
 
 					/* template-import */
-					}elseif ($step == '6') {
+					} elseif ($step == '6') {
 						print '<h2>' . __('Template Setup') . '</h2>';
 
 						print '<p>' . __('Please select the Device Templates that you wish to use after the Install.  If you Operating System is Windows, you need to ensure that you select the \'Windows Device\' Template.  If your Operating System is Linux/UNIX, make sure you select the \'Local Linux Machine\' Device Template.') . '</p>';
@@ -1050,7 +924,7 @@ $enabled = '1';
 						print __('Press \'Finish\' to complete the installation process after selecting your Device Templates.') . '</p>';
 					
 					/* upgrade */
-					}elseif ($step == '8') {
+					} elseif ($step == '8') {
 						print '<h2>' . __('Upgrade Results') . '</h2>';
 
 						print '<p>' . __('You Cacti database has been upgraded.  You can view the results below.') . '</p>';
@@ -1058,21 +932,21 @@ $enabled = '1';
 						$current_version  = '';
 						$upgrade_results = '';
 						$failed_sql_query = false;
+						$cacti_versions = array_keys($cacti_version_codes);
 
 						$sqltext = array();
 						$sqltext[0] = '<span style="color: red; font-weight: bold; font-size: 12px;">' . __('[Fail]') . '</span>&nbsp;';
 						$sqltext[1] = '<span style="color: green; font-weight: bold; font-size: 12px;">' . __('[Success]') . '</span>&nbsp;';
 						$sqltext[2] = '<span style="color: grey; font-weight: bold; font-size: 12px;">' . __('[Not Ran]') . '</span>&nbsp;';
 
-						if (isset($_SESSION['sess_sql_install_cache'])) {
-							foreach ($_SESSION['sess_sql_install_cache'] as $index => $arr1) {
+						if (isset($_SESSION['sess_sql_install_cache']) && is_array($_SESSION['sess_sql_install_cache'])) {
+							foreach ($_SESSION['sess_sql_install_cache'] as $arr1) {
 								foreach ($arr1 as $version => $arr2) {
 									foreach ($arr2 as $status => $sql) {
 										if ($current_version != $version) {
 											$version_index = array_search($version, $cacti_versions);
-											$upgrade_results .= '<p><strong>' . (isset($cacti_versions{$version_index-1}) ? $cacti_versions{$version_index-1}:'')  . ' -> ' . $cacti_versions{$version_index} . "</strong></p>\n";
+											$upgrade_results .= '<p><strong>' . (isset($cacti_versions[$version_index - 1]) ? $cacti_versions[$version_index - 1] : '')  . ' -> ' . $cacti_versions[$version_index] . "</strong></p>\n";
 										}
-
 										$upgrade_results .= "<p class='code'>" . $sqltext[$status] . nl2br($sql) . "</p>\n";
 
 										/* if there are one or more failures, make a note because we are going to print
@@ -1087,7 +961,7 @@ $enabled = '1';
 							}
 
 							kill_session_var('sess_sql_install_cache');
-						}else{
+						} else {
 							print '<em>' . __('No SQL queries have been executed.') . '</em>';
 						}
 
@@ -1098,7 +972,7 @@ $enabled = '1';
 						print $upgrade_results;
 
 					/* upgrade-oldversion */
-					}elseif ($step == '9') {
+					} elseif ($step == '9') {
 						print '<p style="font-size: 16px; font-weight: bold; color: red;">' . __('Important Upgrade Notice') . '</p>';
 						print '<p>' . __('Before you continue with the installation, you <strong>must</strong> update your <tt>/etc/crontab</tt> file to point to <tt>poller.php</tt> instead of <tt>cmd.php</tt>.') . '</p>';
 						print '<p>' . __('See the sample crontab entry below with the change made in red. Your crontab line will look slightly different based upon your setup.') . '</p>';
@@ -1111,7 +985,7 @@ $enabled = '1';
 				<tr>
 					<td class='saveRow' style='text-align:left'>
 						<?php if ($step > 1) {?><input id='previous' type='button' value='<?php print __x('Dialog: previous', 'Previous'); ?>'><?php }?>
-						<input id='next' type='submit' value='<?php if ($step == '9'){ print __x('Dialog: complete', 'Finish'); }else{ print __x('Dialog: go to the next page', 'Next'); }?>'>
+						<input id='next' type='submit' value='<?php if ($step == '9'){ print __x('Dialog: complete', 'Finish'); } else { print __x('Dialog: go to the next page', 'Next'); }?>'>
 						<input id='test' type='button' style='display:none' title='<?php print __('Test remote database connection');?>' value='<?php print __x('Dialog: test connection', 'Test Connection'); ?>'>
 						<input type='hidden' id='previous_step' name='previous_step' value='<?php print $previous_step;?>'>
 					</td>
@@ -1150,7 +1024,7 @@ $(function() {
 	$('#accept').click(function() {
 		if ($(this).is(':checked')) {
 			$('#next').button('enable');
-		}else{
+		} else {
 			$('#next').button('disable');
 		}
 	});
@@ -1159,14 +1033,14 @@ $(function() {
 		// script is handled in the step
 	}else if (enabled) {
 		$('#next').button('enable');
-	}else{
+	} else {
 		$('#next').button('disable');
 	}
 
 	if ($('#accept').length) {
 		if ($('#accept').is(':checked')) {
 			$('#next').button('enable');
-		}else{
+		} else {
 			$('#next').button('disable');
 		}
 	}
@@ -1176,7 +1050,7 @@ $(function() {
 			$('#testdb').button('disable');
 		}else if ($('#database_hostname').val() == '127.0.0.1') {
 			$('#testdb').button('disable');
-		}else{
+		} else {
 			$('#testdb').button('enable');
 		}
 	});
