@@ -26,14 +26,14 @@ function run_data_query($host_id, $snmp_query_id) {
 	global $config, $input_types;
 
 	/* don't run/rerun the query if the host is down, or disabled */
-	$status = db_fetch_row_prepared('SELECT status, disabled FROM host WHERE id = ?', array($host_id));
+	$status = db_fetch_row_prepared('SELECT status, disabled, poller_id FROM host WHERE id = ?', array($host_id));
 	if (!sizeof($status)) {
 		return false;
-	}elseif ($status['status'] == HOST_DOWN || $status['disabled'] == 'on') {
+	} elseif ($status['status'] == HOST_DOWN || $status['disabled'] == 'on') {
 		return true;
 	}
 
-	$poller_id = db_fetch_cell_prepared('SELECT poller_id FROM host WHERE id = ?', array($host_id));
+	$poller_id = $status['poller_id'];
 
 	if ($poller_id != $config['poller_id']) {
 		$hostname = db_fetch_cell_prepared('SELECT hostname FROM poller WHERE id = ?', array($poller_id));
@@ -70,15 +70,17 @@ function run_data_query($host_id, $snmp_query_id) {
 		ON snmp_query.data_input_id=data_input.id 
 		WHERE snmp_query.id = ?', array($snmp_query_id));
 
-	if (isset($input_types[$type_id])) query_debug_timer_offset('data_query', "Found type = '" . $type_id . "' [" . $input_types[$type_id] . "].");
+	if (isset($input_types[$type_id])) {
+		query_debug_timer_offset('data_query', "Found type = '" . $type_id . "' [" . $input_types[$type_id] . "].");
+	}
 
 	if ($type_id == DATA_INPUT_TYPE_SNMP_QUERY) {
 		$result = query_snmp_host($host_id, $snmp_query_id);
-	}elseif ($type_id == DATA_INPUT_TYPE_SCRIPT_QUERY) {
+	} elseif ($type_id == DATA_INPUT_TYPE_SCRIPT_QUERY) {
 		$result = query_script_host($host_id, $snmp_query_id);
-	}elseif ($type_id == DATA_INPUT_TYPE_QUERY_SCRIPT_SERVER) {
+	} elseif ($type_id == DATA_INPUT_TYPE_QUERY_SCRIPT_SERVER) {
 		$result = query_script_host($host_id, $snmp_query_id);
-	}else{
+	} else {
 		$result = false;
 		$arguments = array(
 			'result' => $result, 
@@ -90,7 +92,7 @@ function run_data_query($host_id, $snmp_query_id) {
 
 		if (isset($arguments['result']) && $arguments['result'] !== false) {
 			$result = $arguments['result'];
-		}else{
+		} else {
 			query_debug_timer_offset('data_query', "Unknown type = '$type_id'");
 			unset($result);
 		}
@@ -105,22 +107,23 @@ function run_data_query($host_id, $snmp_query_id) {
 		dl.snmp_index, dtd.local_data_id, dtd.data_input_id,
 		did.data_template_data_id, did.data_input_field_id, did.value
 		FROM data_local AS dl
-		LEFT JOIN data_template_data AS dtd
-		ON dl.id=dtd.local_data_id
-		LEFT JOIN data_input_fields AS dif
+		INNER JOIN data_template_data AS dtd 
+		ON dl.id = dtd.local_data_id
+		INNER JOIN data_input_fields AS dif
 		ON dtd.data_input_id = dif.data_input_id
 		LEFT JOIN data_input_data AS did
 		ON dtd.id = did.data_template_data_id
 		AND dif.id = did.data_input_field_id
-		WHERE dif.type_code="output_type"
+		WHERE dif.type_code = "output_type"
 		AND dl.snmp_query_id = ?
 		AND dl.host_id = ?',
 		array($host_id, $snmp_query_id));
 
+	$bestDataQueryIndexType = get_best_data_query_index_type($host_id, $snmp_query_id);
 	if (sizeof($data_queries)) {
 		foreach($data_queries as $data_query) {
 			/* build array required for function call */
-			$data_query['snmp_index_on']       = get_best_data_query_index_type($host_id, $snmp_query_id);
+			$data_query['snmp_index_on']       = $bestDataQueryIndexType;
 
 			/* as we request the output_type, 'value' gives the snmp_query_graph_id */
 			$data_query['snmp_query_graph_id'] = $data_query['value'];
@@ -148,7 +151,7 @@ function run_data_query($host_id, $snmp_query_id) {
 
 		api_plugin_hook_function('run_data_query', array('host_id' => $host_id, 'snmp_query_id' => $snmp_query_id));
 		query_debug_timer_offset('data_query', 'Plugin hooks complete');
-	}else{
+	} else {
 		if ($config['connection'] == 'online') {
 			automation_execute_data_query($host_id, $snmp_query_id);
 			query_debug_timer_offset('data_query', 'Automation execute data query complete');
@@ -160,7 +163,7 @@ function run_data_query($host_id, $snmp_query_id) {
 		if (!isset($_SESSION)) {
 			$config['debug_log']['result'] = $result;
 			print json_encode($config['debug_log']);
-		}else{
+		} else {
 			$_SESSION['debug_log']['result'] = $result;
 			print json_encode($_SESSION['debug_log']);
 
@@ -491,12 +494,12 @@ function query_snmp_host($host_id, $snmp_query_id) {
 					if(isset($field_array['rewrite_index'])){
 						if(isset($rewritten_indexes[$index])){
 							$oid_suffix = $rewritten_indexes[$index];
-						}else{
+						} else {
 							// we failed to build rewritten index. warnings are sent already, just skip this index silently
 							continue;
 						}
 						$oid .= '.' . $oid_suffix;
-					}else{
+					} else {
 						$oid .= '.' . $index;
 					}
 
@@ -801,7 +804,7 @@ function data_query_rewrite_indexes(&$errmsg, $host_id, $snmp_query_id, $rewrite
 		foreach($chain_indexes as $key => $values){
 			if(isset($values[$num_index]) && preg_match('/^[0-9.]+$/', $values[$num_index])){
 				$index = str_replace("|query_$key|", trim($values[$num_index]), $index);
-			}else{
+			} else {
 				$errmsg[] = "@'" . $num_index . "': could not load value of '$key'";
 			}
 		}
@@ -844,7 +847,7 @@ function rewrite_snmp_enum_value($field_name, $value=NULL, $map=NULL){
 			$newmap[$item['match']] = $item['replace'];
 		}
 		$map = $newmap;
-	}else{
+	} else {
 		$map = unserialize($map);
 	}
 	if($map === FALSE || !is_array($map)){
@@ -859,7 +862,7 @@ function rewrite_snmp_enum_value($field_name, $value=NULL, $map=NULL){
 					$src = '/' . str_replace('/', '\/', $matches[2]) . '/i';
 				else
 					$src = '/' . str_replace('/', '\/', $matches[1]) . '/';
-			}else{
+			} else {
 				$src = '/^' . str_replace('/^', '\/', $src) . '$/';
 			}
 			$mapcache[$field_name][$src] = $dst;
@@ -918,7 +921,7 @@ function data_query_field_list($data_template_data_id) {
 
 	if ((!isset($field['index_type'])) || (!isset($field['index_value'])) || (!isset($field['output_type']))) {
 		return 0;
-	}else{
+	} else {
 		return $field;
 	}
 }
@@ -1054,7 +1057,9 @@ function update_data_source_data_query_cache($local_data_id, $host_id = '', $dat
 		FROM data_template_data
 		WHERE data_template_data.local_data_id = ?', array($local_data_id)));
 
-	if (empty($field)) { return; }
+	if (empty($field)) {
+		return;
+	}
 
 	if (empty($data_query_id)) {
 		$data_query_id = db_fetch_cell_prepared('SELECT snmp_query_id FROM snmp_query_graph WHERE id = ?', array($field['output_type']));
@@ -1182,7 +1187,7 @@ function get_ordered_index_type_list($host_id, $data_query_id, $data_query_index
 	if (isset($raw_xml['index_type'])) {
 		if ($raw_xml['index_type'] == 'nonunique') {
 			$nonunique = 1;
-		}else{
+		} else {
 			$nonunique = 0;
 		}
 	} else {
@@ -1200,12 +1205,13 @@ function get_ordered_index_type_list($host_id, $data_query_id, $data_query_index
 					AND snmp_query_id = ?
 					AND field_name = ?', 
 					array($host_id, $data_query_id, $field_name));
-			}else{
+			} else {
 				$field_values = db_fetch_assoc_prepared("SELECT field_value 
 					FROM host_snmp_cache 
 					WHERE host_id = ?
 					AND snmp_query_id = ?
-					AND field_name = ? AND $sql_or", 
+					AND field_name = ? 
+					AND $sql_or",
 					array($host_id, $data_query_id, $field_name));
 			}
 
@@ -1231,7 +1237,7 @@ function get_ordered_index_type_list($host_id, $data_query_id, $data_query_index
 			}
 		}
 	/* the xml file does not contain a field list, ignore the order */
-	}else{
+	} else {
 		foreach($xml_outputs as $output) {
 			$return_array[] = $output;
 		}
@@ -1255,7 +1261,7 @@ function update_data_query_sort_cache($host_id, $data_query_id) {
 	/* something is probably wrong with the data query */
 	if (sizeof($valid_index_types) == 0) {
 		$sort_field = '';
-	}else{
+	} else {
 		/* grab the first field off the list */
 		$sort_field = $valid_index_types[0];
 	}
@@ -1263,7 +1269,7 @@ function update_data_query_sort_cache($host_id, $data_query_id) {
 	/* substitute variables */
 	if (isset($raw_xml['index_title_format'])) {
 		$title_format = str_replace('|chosen_order_field|', "|query_$sort_field|", $raw_xml['index_title_format']);
-	}else{
+	} else {
 		$title_format = "|query_$sort_field|";
 	}
 
@@ -1321,7 +1327,7 @@ function get_script_query_path($args, $script_path, $host_id) {
 	/* get any extra arguments that need to be passed to the script */
 	if (!empty($args)) {
 		$extra_arguments = substitute_host_data($args, '|', '|', $host_id);
-	}else{
+	} else {
 		$extra_arguments = '';
 	}
 
@@ -1378,18 +1384,18 @@ function verify_index_order($raw_xml) {
  */
 function update_snmp_index_order($data_query) {
 	if (sizeof($data_query)) {
-		$data_input_field = array_rekey(db_fetch_assoc_prepared('SELECT 
+		$data_input_field = array_rekey(db_fetch_assoc_prepared("SELECT 
 			data_input_fields.id, 
-			data_input_fields.type_code 
-			FROM (snmp_query,data_input,data_input_fields) 
-			WHERE snmp_query.data_input_id=data_input.id 
-			AND data_input.id=data_input_fields.data_input_id 
-			AND (data_input_fields.type_code="index_type" 
-			OR data_input_fields.type_code="index_value" 
-			OR data_input_fields.type_code="output_type") 
-			AND snmp_query.id = ?', 
+			data_input_fields.type_code
+			FROM snmp_query
+			INNER JOIN data_input
+			ON snmp_query.data_input_id = data_input.id
+			INNER JOIN data_input_fields
+			ON data_input.id = data_input_fields.data_input_id 
+			WHERE data_input_fields.type_code IN('index_type', 'index_value', 'output_type') 
+			AND snmp_query.id = ?",
 			array($data_query['snmp_query_id'])), 'type_code', 'id');
-		
+
 		$snmp_cache_value = db_fetch_cell_prepared('SELECT field_value 
 			FROM host_snmp_cache 
 			WHERE host_id = ?
@@ -1397,25 +1403,23 @@ function update_snmp_index_order($data_query) {
 			AND field_name = ?
 			AND snmp_index = ?', 
 			array($data_query['host_id'], $data_query['snmp_query_id'], $data_query['snmp_index_on'], $data_query['snmp_index']));
-		
-		/* save the value to index on (ie. ifindex, ifip, etc) */
+
 		db_execute_prepared('REPLACE INTO data_input_data 
 			(data_input_field_id, data_template_data_id, t_value, value)
-			VALUES (?, ?, "", ?)', 
-			array($data_input_field['index_type'], $data_query['data_template_data_id'], $data_query['snmp_index_on']));
-		
-		/* save the actual value (ie. 3, 192.168.1.101, etc) */
-		db_execute_prepared('REPLACE INTO data_input_data 
-			(data_input_field_id,data_template_data_id,t_value,value) 
-			VALUES (?, ?, "", ?)', 
-			array($data_input_field['index_value'], $data_query['data_template_data_id'], $snmp_cache_value));
-		
-		/* set the expected output type (ie. bytes, errors, packets) */
-		db_execute_prepared('REPLACE INTO data_input_data 
-			(data_input_field_id,data_template_data_id,t_value,value) 
-			VALUES (?, ?, "", ?)', 
-			array($data_input_field['output_type'], $data_query['data_template_data_id'], $data_query['snmp_query_graph_id']));
-		
+			VALUES 
+			(?, ?, "", ?), 
+			(?, ?, "", ?), 
+			(?, ?, "", ?)',
+			array(
+				/* save the value to index on (ie. ifindex, ifip, etc) */
+				$data_input_field['index_type'], $data_query['data_template_data_id'], $data_query['snmp_index_on'],
+				/* save the actual value (ie. 3, 192.168.1.101, etc) */
+				$data_input_field['index_value'], $data_query['data_template_data_id'], $snmp_cache_value,
+				/* set the expected output type (ie. bytes, errors, packets) */
+				$data_input_field['output_type'], $data_query['data_template_data_id'], $data_query['snmp_query_graph_id']
+			)
+		);
+
 		/* now that we have put data into the 'data_input_data' table, update the snmp cache for ds's */
 		update_data_source_data_query_cache($data_query['local_data_id']);
 	}
