@@ -35,50 +35,61 @@ function draw_edit_form($array) {
 		foreach ($array as $top_branch => $top_children) {
 			if ($top_branch == 'config') {
 				$config_array = $top_children;
-			}elseif ($top_branch == 'fields') {
+			} elseif ($top_branch == 'fields') {
 				$fields_array = $top_children;
 			}
 		}
 	}
 
-	$i = 0;
 	if (sizeof($fields_array) > 0) {
+		if (!isset($config_array['no_form_tag'])) {
+			print "<form method='post' autocomplete='off' action='" . ((isset($config_array['post_to'])) ? $config_array['post_to'] : get_current_page()) . "'" . ((isset($config_array['form_name'])) ? " name='" . $config_array['form_name'] . "'" : '') . ((isset($config_array['enctype'])) ? " enctype='" . $config_array['enctype'] . "'" : '') . ">\n";
+		}
+
+		$i = 0;
+		$row_class = 'odd';
+
 		foreach ($fields_array as $field_name => $field_array) {
-			if ($i == 0) {
-				if (!isset($config_array['no_form_tag'])) {
-					print "<tr style='display:none;'><td><form method='post' autocomplete='off' action='" . ((isset($config_array['post_to'])) ? $config_array['post_to'] : get_current_page()) . "'" . ((isset($config_array['form_name'])) ? " name='" . $config_array['form_name'] . "'" : '') . ((isset($config_array['enctype'])) ? " enctype='" . $config_array['enctype'] . "'" : '') . "></td></tr>\n";
-				}
-			}
-
 			if ($field_array['method'] == 'hidden') {
+				print '<div class="hidden formRow">';
 				form_hidden_box($field_name, $field_array['value'], ((isset($field_array['default'])) ? $field_array['default'] : ''), true);
-			}elseif ($field_array['method'] == 'hidden_zero') {
+				print '</div>';
+			} elseif ($field_array['method'] == 'hidden_zero') {
+				print '<div class="hidden formRow">';
 				form_hidden_box($field_name, $field_array['value'], '0', true);
-			}elseif ($field_array['method'] == 'spacer') {
-				if (isset($field_array['collapsible']) && $field_array['collapsible'] == 'true') {
-					$collapsible = true;
-				}else{
-					$collapsible = false;
-				}
+				print '</div>';
+			} elseif ($field_array['method'] == 'spacer') {
+				$collapsible = (isset($field_array['collapsible']) && $field_array['collapsible'] == 'true');
 
-				print "<tr class='spacer tableHeader" . ($collapsible ? ' collapsible':'') . "' id='row_$field_name'><td colspan='2' style='cursor:pointer;' class='tableSubHeaderColumn'>" . $field_array['friendly_name'] . ($collapsible ? "<div style='float:right;padding-right:4px;'><i class='fa fa-angle-double-up'></i></div>":'') . "</td></tr>\n";
-			}else{
+				print "<div class='spacer formHeader" . ($collapsible ? ' collapsible':'') . "' id='row_$field_name'><div class='formHeaderText'>" . $field_array['friendly_name'] . ($collapsible ? "<div class='formHeaderAnchor'><i class='fa fa-angle-double-up'></i></div>":'') . '</div></div>';
+			} else {
+				// Make a row using a div
 				if (isset($config_array['force_row_color'])) {
-					print "<tr class='formRow even-alternate'>";
-				}else{
-					form_alternate_row('row_' . $field_name);
+					print "<div id='row_$field_name' class='formRow even-alternate $row_class'>";
+				} else {
+					print "<div id='row_$field_name' class='formRow $row_class'>";
+					if ($row_class == 'even') {
+						$row_class = 'odd';
+					} else {
+						$row_class = 'even';
+					}
 				}
 
-				print "<td class='formRow' style='width:" . ((isset($config_array['left_column_width'])) ? $config_array['left_column_width'] . 'px;':'50%;') . "'>\n<span class='formItemName'>" . $field_array['friendly_name'] . "</span>\n";
+				// Make a form cell
+				print "<div class='formColumnLeft'>";
 
+				print "<div class='formFieldName'>" . $field_array['friendly_name'];
 				if (read_config_option('hide_form_description') == 'on') {
-					print '<br><span class="formItemDescription">' . ((isset($field_array['description'])) ? $field_array['description'] : '') . "<br></span>\n";
-				}else{
+					print '<br><span class="formFieldDescription">' . ((isset($field_array['description'])) ? $field_array['description'] : '') . "</span>\n";
+				} else {
+					print '<div class="formTooltip">';
 					print display_tooltip((isset($field_array['description'])) ? $field_array['description'] : '');
+					print '</div>';
 				}
 
 				if (isset($field_array['sub_checkbox'])) {
-					print "<br>\n";
+					print '<br>';
+					print '<div class="formSubCheckbox">';
 					form_checkbox($field_array['sub_checkbox']['name'],
 						$field_array['sub_checkbox']['value'],
 						$field_array['sub_checkbox']['friendly_name'],
@@ -86,13 +97,23 @@ function draw_edit_form($array) {
 						((isset($field_array['sub_checkbox']['form_id'])) 	? $field_array['sub_checkbox']['form_id'] : ''),
 						((isset($field_array['sub_checkbox']['class'])) 	? $field_array['sub_checkbox']['class'] : ''),
 						((isset($field_array['sub_checkbox']['on_change'])) ? $field_array['sub_checkbox']['on_change'] : ''));
+					print '</div>';
 				}
+				print '</div>';
 
-				print "</td>\n<td>\n";
+				// End form cell
+				print '</div>'; 
+
+				// New form column for content
+				print '<div class="formColumnRight"><div class="formData">'; 
 
 				draw_edit_control($field_name, $field_array);
 
-				print "</td>\n</tr>\n";
+				// End content column
+				print '</div></div>';
+
+				// End form row
+				print '</div>';
 			}
 
 			$i++;
@@ -291,7 +312,7 @@ function draw_edit_control($field_name, &$field_array) {
 		form_color_dropdown(
 			$field_name, 
 			$field_array['value'], 
-			'None',
+			__('None'),
 			((isset($field_array['default'])) ? $field_array['default'] : ''),
 			((isset($field_array['class'])) ? $field_array['class'] : ''),
 			((isset($field_array['on_change'])) ? $field_array['on_change'] : '')
@@ -329,6 +350,7 @@ function draw_edit_control($field_name, &$field_array) {
 
 		break;
 	case 'radio':
+		print "<div style='formRadio'>";
 		foreach ($field_array['items'] as $radio_index => $radio_array) {
 			form_radio_button(
 				$field_name, 
@@ -342,6 +364,7 @@ function draw_edit_control($field_name, &$field_array) {
 
 			print '<br>';
 		}
+		print "</div>";
 
 		break;
 	case 'custom':
@@ -385,9 +408,18 @@ function draw_edit_control($field_name, &$field_array) {
 			((isset($field_array['on_click'])) ? $field_array['on_click'] : '')
 		);
 
+		break;
+	case 'submit':
+		form_submit(
+			$field_name, 
+			((isset($field_array['value'])) ? $field_array['value'] : ''),
+			((isset($field_array['title'])) ? $field_array['title'] : ''),
+			((isset($field_array['on_click'])) ? $field_array['on_click'] : '')
+		);
+
 		break;
 	default:
-		print '<em id="' . $field_name . '">' . htmlspecialchars($field_array['value'],ENT_QUOTES) . '</em>';
+		print '<em>' . htmlspecialchars($field_array['value'], ENT_QUOTES, 'UTF-8') . '</em>';
 
 		form_hidden_box($field_name, $field_array['value'], '', true);
 
@@ -401,7 +433,21 @@ function draw_edit_control($field_name, &$field_array) {
    @arg $title - the hover title for the button
    @arg $action - the onClick action for the button */
 function form_button($form_name, $value, $title = '', $action = '') {
-	print "<input role='button' type='button' " . 
+	print "<input type='button' " . 
+		"id='$form_name' " . 
+		"name='$form_name' " . 
+		"value='$value' " . 
+		($action!='' ? "onClick='$action'":"") . 
+		($title!='' ? "title='$title'":"") . ">";
+}
+
+/* form_button - draws a standard button form element
+   @arg $form_name - the name of this form element
+   @arg $value - the display value for the button
+   @arg $title - the hover title for the button
+   @arg $action - the onClick action for the button */
+function form_submit($form_name, $value, $title = '', $action = '') {
+	print "<input type='submit' " . 
 		"id='$form_name' " . 
 		"name='$form_name' " . 
 		"value='$value' " . 
@@ -465,7 +511,7 @@ function form_filepath_box($form_name, $form_previous_value, $form_default_value
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __('Path is a Directory and not a File') . "'></span>";
 	}else if (strlen($form_previous_value) == 0) {
 		$extra_data = '';
-	}else{
+	} else {
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __('File is Not Found'). "'></span>";
 	}
 
@@ -510,7 +556,7 @@ function form_dirpath_box($form_name, $form_previous_value, $form_default_value,
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __('Path is a File and not a Directory'). "></span>";
 	}else if (strlen($form_previous_value) == 0) {
 		$extra_data = '';
-	}else{
+	} else {
 		$extra_data = "<span class='cactiTooltipHint fa fa-times-circle' style='padding:5px;font-size:16px;color:red' title='" . __('Directory is Not found'). "'></span>";
 	}
 
@@ -562,9 +608,7 @@ function form_hidden_box($form_name, $form_previous_value, $form_default_value,
 		$form_previous_value = $form_default_value;
 	}
 
-	print ($in_form) ? "<tr style='display:none;'><td colspan='2'>\n":'';
-	print "<input style='height:0px;' type='hidden' id='$form_name' name='$form_name' value='" . htmlspecialchars($form_previous_value, ENT_QUOTES) . "'>\n";
-	print ($in_form) ? "</td></tr>\n":'';
+	print "<div style='display:none;'><input style='height:0px;' type='hidden' id='$form_name' name='$form_name' value='" . htmlspecialchars($form_previous_value, ENT_QUOTES) . "'></div>";
 }
 
 /* form_dropdown - draws a standard html dropdown box
@@ -661,7 +705,7 @@ function form_callback($form_name, $classic_sql, $column_display, $column_id, $c
 		html_create_list($form_data, $column_display, $column_id, htmlspecialchars($previous_id, ENT_QUOTES));
 
 		print "</select>\n";
-	}else{
+	} else {
 		$form_prefix = htmlspecialchars($form_name);
 
 		print "<span id='$form_prefix" . "_wrap' style='width:200px;' class='ui-selectmenu-button ui-widget ui-state-default ui-corner-all'>\n";
@@ -696,7 +740,7 @@ function form_callback($form_name, $classic_sql, $column_display, $column_id, $c
 					$('#<?php print $form_prefix;?>_input').autocomplete('close');
 					clearTimeout(<?php print $form_name;?>Timer);
 					<?php print $form_name;?>Open = false;
-				}else{
+				} else {
 					<?php print $form_name;?>ClickTimer = setTimeout(function() {
 						$('#<?php print $form_prefix;?>_input').autocomplete('search', $('#<?php print $form_prefix;?>_input').val());
 						clearTimeout(<?php print $form_name;?>Timer);
@@ -755,7 +799,7 @@ function form_checkbox($form_name, $form_previous_value, $form_caption, $form_de
 	}
 
 	if (strlen($class)) {
-		$class = " class='$class'";
+		$class = ' ' . trim($class);
 	}
 
 	if (strlen($on_change)) {
@@ -764,11 +808,11 @@ function form_checkbox($form_name, $form_previous_value, $form_caption, $form_de
 
 	if ($form_previous_value == 'on') {
 		$checked = " checked aria-checked='true'";
-	}else{
+	} else {
 		$checked = " aria-checked='false'";
 	}
 
-	print "<input type='checkbox' id='$form_name' name='$form_name'" . $on_change . $class . $checked . ">" . ($form_caption != '' ? " <label for='$form_name'>$form_caption</label>\n":"");
+	print "<input class='formCheckbox$class' type='checkbox' id='$form_name' name='$form_name'" . $on_change . $checked . ">" . ($form_caption != '' ? " <label class='formCheckboxLabel' for='$form_name'>$form_caption</label>\n":"");
 }
 
 /* form_radio_button - draws a standard html radio button
@@ -799,13 +843,13 @@ function form_radio_button($form_name, $form_previous_value, $form_current_value
 
 	if ($form_previous_value == $form_current_value) {
 		$checked = " checked aria-checked='true'";
-	}else{
+	} else {
 		$checked = " aria-checked='false'";
 	}
 
 	$css_id = $form_name . '_' . $form_current_value;
 
-	print "<input role='radio' type='radio' id='$css_id' name='$form_name' value='$form_current_value'" . $class . $on_change . $checked . "><label for='$css_id'>$form_caption</label>\n";
+	print "<input type='radio' id='$css_id' name='$form_name' value='$form_current_value'" . $class . $on_change . $checked . "><label for='$css_id'>$form_caption</label>\n";
 }
 
 /* form_text_area - draws a standard html text area box
@@ -864,7 +908,7 @@ function form_multi_dropdown($form_name, $array_display, $sql_previous_values, $
 		foreach($values as $value) {
 			$sql_previous_values[][$column_id] = $value;
 		}
-	}elseif ($sql_previous_values == '') {
+	} elseif ($sql_previous_values == '') {
 		$values = db_fetch_cell_prepared('SELECT value FROM settings WHERE name = ?', array($form_name));
 		if ($values != '') {
 			$values = explode(',', $values);
@@ -929,7 +973,7 @@ function form_color_dropdown($form_name, $form_previous_value, $form_none_entry,
 
 	if (strlen($class)) {
 		$class = " class='colordropdown $class' ";
-	}else{
+	} else {
 		$class = " class='colordropdown'";
 	}
 
@@ -953,7 +997,7 @@ function form_color_dropdown($form_name, $form_previous_value, $form_none_entry,
 		foreach ($colors_list as $color) {
 			if ($color['name'] == '') {
 				$display = 'Cacti Color (' . $color['hex'] . ')';
-			}else{
+			} else {
 				$display = $color['name'] . ' (' . $color['hex'] . ')';
 			}
 			print "<option data-color='" . $color['hex'] . "' data-style='background-color: #" . $color['hex'] . "' style='background-color: #" . $color['hex'] . ";' value='" . $color['id'] . "'";
@@ -1065,28 +1109,28 @@ function form_save_button($cancel_url, $force_type = '', $key_field = 'id', $aja
 	if (empty($force_type) || $force_type == 'return') {
 		if (isempty_request_var($key_field)) {
 			$alt = __('Create');
-		}else{
+		} else {
 			$alt = __('Save');
 
 			if (strlen($force_type)) {
 				$calt   = __('Return');
-			}else{
+			} else {
 				$calt   = __('Cancel');
 			}
 		}
-	}elseif ($force_type == 'save') {
+	} elseif ($force_type == 'save') {
 		$alt = __('Save');
-	}elseif ($force_type == 'create') {
+	} elseif ($force_type == 'create') {
 		$alt = __('Create');
-	}elseif ($force_type == 'import') {
+	} elseif ($force_type == 'import') {
 		$alt = __('Import');
-	}elseif ($force_type == 'export') {
+	} elseif ($force_type == 'export') {
 		$alt = __('Export');
 	}
 
 	if ($force_type != 'import' && $force_type != 'export' && $force_type != 'save' && $cancel_url != '') {
 		$cancel_action = "<input type='button' onClick='cactiReturnTo(\"" . $cancel_url . "\")' value='" . $calt . "'>";
-	}else{
+	} else {
 		$cancel_action = '';
 	}
 
@@ -1133,7 +1177,7 @@ function form_start($action, $id = '') {
 	if ($id == '') {
 		$form_id = 'form' . $counter;
 		$counter++;
-	}else{
+	} else {
 		$form_id = trim($id);
 	}
 
