@@ -63,7 +63,7 @@ function grow_dropdown_tree($tree_id, $parent = 0, $form_name = '', $selected_tr
 
 			if ($selected_tree_item_id == $leaf['id']) {
 				$html_selected = ' selected';
-			}else{
+			} else {
 				$html_selected = '';
 			}
 
@@ -102,7 +102,7 @@ function grow_dhtml_trees() {
 					ORDER BY graph_tree.id 
 					LIMIT 1',
 					array($_SESSION['sess_user_id']));
-			}else{
+			} else {
 				$default_tree_id = db_fetch_cell('SELECT graph_tree.id 
 					FROM graph_tree
 					INNER JOIN user_auth_perms ON user_auth_perms.item_id = graph_tree.id
@@ -114,7 +114,7 @@ function grow_dhtml_trees() {
 					array($_SESSION['sess_user_id']));
 			}
 		}
-	}else{
+	} else {
 		$default_tree_id = db_fetch_cell('SELECT id FROM graph_tree ORDER BY sequence LIMIT 1');
 	}
 
@@ -130,7 +130,7 @@ function grow_dhtml_trees() {
 	<?php
 	if (isset_request_var('hyper')) {
 		$path = get_tree_path();
-	}elseif (!isset_request_var('node')) {
+	} elseif (!isset_request_var('node')) {
 		$path = array('tree_anchor-' . $default_tree_id . '-anchor');
 		set_request_var('hyper', 'true');
 	}
@@ -141,7 +141,7 @@ function grow_dhtml_trees() {
 	function resizeGraphContent() {
 		if ('<?php print get_selected_theme();?>' != 'classic') {
 			$('.cactiGraphContentArea').css('margin-left', parseInt($('#navigation').width()+10)+'px');
-		}else{
+		} else {
 			width = $(document).width() - $('.cactiTreeNavigationArea').width() - 22;
 			$('.cactiGraphContentArea').css('width', width).css('float', 'right');
 		}
@@ -176,7 +176,7 @@ function grow_dhtml_trees() {
 					if (data.node.id.search('tree_anchor') >= 0) {
 						href=$('#'+data.node.id).find('a:first').attr('href');
 						//href=$('#'+data.node.id).find('a:first').attr('href')+"&node=0";
-					}else{
+					} else {
 						//href=$('#'+data.node.id).find('a:first').attr('href')+"&node="+data.node.id.replace('tbranch-','');
 						href=$('#'+data.node.id).find('a:first').attr('href');
 					}
@@ -285,7 +285,7 @@ function get_tree_path() {
 
 			$linknode = db_fetch_row_prepared('SELECT * 
 				FROM graph_tree_items 
-				WHERE id = ?', 
+				WHERE id = ?',
 				array($node));
 
 			if (sizeof($linknode)) {
@@ -318,7 +318,7 @@ function get_tree_path() {
 							FROM graph_tree_items
 							WHERE id = ?',
 							array($linknode['parent']));
-					}else{
+					} else {
 						break;
 					}
 				}
@@ -326,20 +326,18 @@ function get_tree_path() {
 				$rnodes = array_reverse($rnodes);
 				$nodes = array_merge($nodes, $rnodes);
 			}
-		}elseif (strpos(get_request_var('node'), 'tree_anchor') !== false) {
+		} elseif (strpos(get_request_var('node'), 'tree_anchor') !== false) {
 			$parts = explode('-', get_request_var('node'));
 			$nodes[] = 'tree_anchor-' . $parts[1] . '_anchor';
 		}
 
 		return $nodes;
-	}else{
+	} else {
 		return array();
 	}
 }
 
-function draw_dhtml_tree_level($tree_id, $parent = 0, $graphing = false) {
-	global $config;
-
+function draw_dhtml_tree_level($tree_id, $parent = 0) {
 	$dhtml_tree = array();
 
 	$heirarchy = get_allowed_tree_level($tree_id, $parent);
@@ -349,9 +347,9 @@ function draw_dhtml_tree_level($tree_id, $parent = 0, $graphing = false) {
 		foreach ($heirarchy as $leaf) {
 			if ($leaf['host_id'] > 0) {  //It's a host
 				$dhtml_tree[] = "\t\t\t\t<li id='tbranch:" . $leaf['id'] . "_thost:" . $leaf['host_id'] . "' data-jstree='{ \"type\" : \"device\" }'>Device: " . htmlspecialchars($leaf['hostname']) . "</li>\n";
-			}elseif ($leaf['local_graph_id'] > 0) {
+			} elseif ($leaf['local_graph_id'] > 0) {
 				$dhtml_tree[] = "\t\t\t\t<li id='tbranch:" . $leaf['id'] . "_tgraph:" . $leaf['local_graph_id'] . "' data-jstree='{ \"type\" : \"graph\" }'>Graph: " . htmlspecialchars(get_graph_title($leaf['local_graph_id'])) . "</a></li>\n";
-			}else{ //It's not a host
+			} else { //It's not a host
 				$dhtml_tree[] = "\t\t\t\t<li class='jstree-closed' id='tbranch:" . $leaf['id'] . "'>" . htmlspecialchars($leaf['title']) . "</li>\n";
 			}
 		}
@@ -362,7 +360,7 @@ function draw_dhtml_tree_level($tree_id, $parent = 0, $graphing = false) {
 	return $dhtml_tree;
 }
 
-function draw_dhtml_tree_level_graphing($tree_id, $parent = 0, $export = false) {
+function draw_dhtml_tree_level_graphing($tree_id, $parent = 0) {
 	global $config;
 
 	include_once($config['base_path'] . '/lib/data_query.php');
@@ -388,7 +386,7 @@ function draw_dhtml_tree_level_graphing($tree_id, $parent = 0, $export = false)
 									$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . "-gt-" . $graph_template['id'] . "' data-jstree='{ \"type\" : \"graph_template\" }'><a href='" . htmlspecialchars('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&hgd=gt:' . $graph_template['id']) . "'>" . htmlspecialchars($graph_template['name']) . "</a></li>\n";
 								}
 							}
-						}else if ($leaf['host_grouping_type'] == HOST_GROUPING_DATA_QUERY_INDEX) {
+						} elseif ($leaf['host_grouping_type'] == HOST_GROUPING_DATA_QUERY_INDEX) {
 							$data_queries = db_fetch_assoc_prepared('SELECT sq.id, sq.name
 								FROM graph_local AS gl
 								INNER JOIN snmp_query AS sq
@@ -403,20 +401,25 @@ function draw_dhtml_tree_level_graphing($tree_id, $parent = 0, $export = false)
 							));
 
 							if (sizeof($data_queries)) {
+								$ntg = get_allowed_graphs('gl.host_id=' . $leaf['host_id'] . ' AND gl.snmp_query_id=0');
+
 								foreach ($data_queries as $data_query) {
-									/* fetch a list of field names that are sorted by the preferred sort field */
-									$sort_field_data = get_formatted_data_query_indexes($leaf['host_id'], $data_query['id']);
 									if ($data_query['id'] == 0) {
-										$non_template_graphs = get_allowed_graphs('gl.host_id=' . $leaf['host_id'] . ' AND gl.snmp_query_id=0');
-									}else{
-										$non_template_graphs = 0;
+										$non_template_graphs = $ntg;
+										$sort_field_data     = array();
+									} else {
+										$non_template_graphs = array();
+
+										/* fetch a list of field names that are sorted by the preferred sort field */
+										$sort_field_data     = get_formatted_data_query_indexes($leaf['host_id'], $data_query['id']);
 									}
-	
-									if ((($data_query['id'] == 0) && (sizeof($non_template_graphs))) ||
-										(($data_query['id'] > 0) && (sizeof($sort_field_data) > 0))) {
+
+									if (($data_query['id'] == 0 && sizeof($non_template_graphs)) ||
+										($data_query['id'] > 0 && sizeof($sort_field_data) > 0)
+									) {
 										if ($data_query['name'] != 'Non Query Based') {
 											$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . "-dq-" . $data_query['id'] . "' data-jstree='{ \"type\" : \"data_query\" }'><a class='treepick' href=\"" . htmlspecialchars('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . "&hgd=dq:" . $data_query['id']) . '">' . htmlspecialchars($data_query['name']) . "</a>\n";
-										}else{
+										} else {
 											$dhtml_tree[] = "\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . '-dq-' . $data_query['id'] . "' data-jstree='{ \"type\" : \"data_query\" }'><a class='treepick' href=\"" . htmlspecialchars('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . "&hgd=dq:" . $data_query['id']) . '">' . htmlspecialchars($data_query['name']) . "</a>\n";
 										}
 
@@ -440,7 +443,7 @@ function draw_dhtml_tree_level_graphing($tree_id, $parent = 0, $export = false)
 					}
 	
 					$dhtml_tree[] = "\t\t\t\t</li>\n";
-				}else{ //It's not a host
+				} else { //It's not a host
 					$children = db_fetch_cell_prepared('SELECT COUNT(*) FROM graph_tree_items WHERE parent = ? AND local_graph_id=0', array($leaf['id']));
 
 					$dhtml_tree[] = "\t\t\t\t<li id='tbranch-" . $leaf['id'] . "' " . ($children > 0 ? "class='jstree-closed'":"") . "><a href=\"" . htmlspecialchars('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&hgd=') . '">' . htmlspecialchars($leaf['title']) . "</a></li>\n";
@@ -448,7 +451,7 @@ function draw_dhtml_tree_level_graphing($tree_id, $parent = 0, $export = false)
 			}
 	
 			$dhtml_tree[] = "\t\t\t</ul>\n";
-		}else{
+		} else {
 			$dhtml_tree[] = "<ul>\n";
 			foreach($heirarchy as $h) {
 				$dhtml_tree[] = "<li id='tree_anchor-" . $h['tree_id'] . "' data-jstree='{ \"type\" : \"tree\" }' class='jstree-closed'><a href='" . htmlspecialchars('graph_view.php?action=tree&node=tree_anchor-' . $h['tree_id'] . '&hgd=') . "'>" . htmlspecialchars($h['title']) . "</a></li>\n";
@@ -461,11 +464,9 @@ function draw_dhtml_tree_level_graphing($tree_id, $parent = 0, $export = false)
 }
 
 function create_dhtml_tree() {
-	global $config;
-
 	$dhtml_tree = array();
 
-	$tree_list = get_graph_tree_array();
+	$tree_list = get_allowed_trees();
 
 	if (sizeof($tree_list)) {
 		foreach ($tree_list as $tree) {
@@ -578,10 +579,10 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 	if ($host_group_data_array[0] == 'gt') {
 		$host_group_data_name = '<strong>' . __('Graph Template:'). '</strong> ' . db_fetch_cell_prepared('SELECT name FROM graph_templates WHERE id = ?', array($host_group_data_array[1]));
 		$graph_template_id = $host_group_data_array[1];
-	}elseif ($host_group_data_array[0] == 'dq') {
+	} elseif ($host_group_data_array[0] == 'dq') {
 		$host_group_data_name = '<strong>' . __('Graph Template:') . '</strong> ' . (empty($host_group_data_array[1]) ? 'Non Query Based' : db_fetch_cell_prepared('SELECT name FROM snmp_query WHERE id = ?', array($host_group_data_array[1])));
 		$data_query_id = $host_group_data_array[1];
-	}elseif ($host_group_data_array[0] == 'dqi') {
+	} elseif ($host_group_data_array[0] == 'dqi') {
 		$host_group_data_name = '<strong>' . __('Graph Template:') . '</strong> ' . (empty($host_group_data_array[1]) ? 'Non Query Based' : db_fetch_cell_prepared('SELECT name FROM snmp_query WHERE id = ?', array($host_group_data_array[1]))) . '-> ' . (empty($host_group_data_array[2]) ? 'Template Based' : get_formatted_data_query_index($leaf['host_id'], $host_group_data_array[1], $host_group_data_array[2]));
 		$data_query_id = $host_group_data_array[1];
 		$data_query_index = $host_group_data_array[2];
@@ -660,9 +661,9 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<select id='graphs' onChange='applyGraphFilter()'>
 							<?php
 							if (sizeof($graphs_per_page) > 0) {
-							foreach ($graphs_per_page as $key => $value) {
-								print "<option value='" . $key . "'"; if (get_request_var('graphs') == $key) { print ' selected'; } print '>' . $value . "</option>\n";
-							}
+								foreach ($graphs_per_page as $key => $value) {
+									print "<option value='" . $key . "'"; if (get_request_var('graphs') == $key) { print ' selected'; } print '>' . $value . "</option>\n";
+								}
 							}
 							?>
 						</select>
@@ -883,7 +884,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 			if (date1Open) {
 				date1Open = false;
 				$('#date1').datetimepicker('hide');
-			}else{
+			} else {
 				date1Open = true;
 				$('#date1').datetimepicker('show');
 			}
@@ -893,7 +894,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 			if (date2Open) {
 				date2Open = false;
 				$('#date2').datetimepicker('hide');
-			}else{
+			} else {
 				date2Open = true;
 				$('#date2').datetimepicker('show');
 			}
@@ -963,7 +964,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 		}
 
 		$graph_list = get_allowed_tree_header_graphs($tree_id, $leaf_id, $sql_where);
-	}elseif ($leaf_type == 'host') {
+	} elseif ($leaf_type == 'host') {
 		/* graph template grouping */
 		if ($leaf['host_grouping_type'] == HOST_GROUPING_GRAPH_TEMPLATE) {
 			$sql_where = 'gl.host_id=' . $leaf['host_id'] . (empty($graph_template_id) ? '' : ' AND gl.graph_template_id=' . $graph_template_id);
@@ -1003,7 +1004,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 				}
 			}
 		/* data query index grouping */
-		}elseif ($leaf['host_grouping_type'] == HOST_GROUPING_DATA_QUERY_INDEX) {
+		} elseif ($leaf['host_grouping_type'] == HOST_GROUPING_DATA_QUERY_INDEX) {
 			$data_queries = db_fetch_assoc("SELECT sq.id, sq.name
 				FROM graph_local AS gl
 				INNER JOIN snmp_query AS sq
@@ -1092,7 +1093,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 
 	if (get_request_var('thumbnails') == 'true' || get_request_var('thumbnails') == 'on') {
 		html_graph_thumbnail_area($new_graph_list, '', 'view_type=tree&graph_start=' . get_current_graph_start() . '&graph_end=' . get_current_graph_end(), '', get_request_var('columns'));
-	}else{
+	} else {
 		html_graph_area($new_graph_list, '', 'view_type=tree&graph_start=' . get_current_graph_start() . '&graph_end=' . get_current_graph_end(), '', get_request_var('columns'));
 	}
 
